Package com.rollbar

Class Rollbar

java.lang.Object
com.rollbar.Rollbar

@Deprecated public class Rollbar extends Object
Deprecated.
This class is deprecated and provided as a convenience to ease the migration path. from 0.5.4 to 1.0.0. For the simplest use cases, this class should provide the same functionality as the old com.rollbar.Rollbar class by delegating to the new com.rollbar.notifier.Rollbar class. For any new usage, do not use this class, prefer com.rollbar.notifier.Rollbar.
  • Constructor Summary

    Constructors
    Constructor
    Description
    Rollbar(String accessToken, String environment)
    Deprecated.
    Construct a notifier defaults for everything including Sender.
    Rollbar(String accessToken, String environment, Sender sender)
    Deprecated.
    Construct notifier, defaults for everything but Sender.
    Rollbar(String accessToken, String environment, Sender sender, String codeVersion, String platform, String language, String framework, String context, com.rollbar.api.payload.data.Request request, com.rollbar.api.payload.data.Person person, com.rollbar.api.payload.data.Server server, Map<String,Object> custom, com.rollbar.api.payload.data.Notifier notifier, SenderListener responseHandler, Filter filter, Transformer transform)
    Deprecated.
    Construct notifier with static values for all configuration options set.
  • Method Summary

    Modifier and Type
    Method
    Description
    void
    critical(String message)
    Deprecated.
    Record a critical message.
    void
    critical(String message, Map<String,Object> custom)
    Deprecated.
    Record a critical message with extra information attached.
    void
    Deprecated.
    Record a critical error.
    void
    critical(Throwable error, String description)
    Deprecated.
    Record a critical error with human readable description.
    void
    critical(Throwable error, Map<String,Object> custom)
    Deprecated.
    Record a critical error with extra information attached.
    void
    critical(Throwable error, Map<String,Object> custom, String description)
    Deprecated.
    Record a critical error with custom parameters and human readable description.
    void
    debug(String message)
    Deprecated.
    Record a debugging message.
    void
    debug(String message, Map<String,Object> custom)
    Deprecated.
    Record a debugging message with extra information attached.
    void
    Deprecated.
    Record an error as debugging information.
    void
    debug(Throwable error, String description)
    Deprecated.
    Record a debug error with human readable description.
    void
    debug(Throwable error, Map<String,Object> custom)
    Deprecated.
    Record a debug error with extra information attached.
    void
    debug(Throwable error, Map<String,Object> custom, String description)
    Deprecated.
    Record a debug error with custom parameters and human readable description.
    void
    error(String message)
    Deprecated.
    Record an error message.
    void
    error(String message, Map<String,Object> custom)
    Deprecated.
    Record a error message with extra information attached.
    void
    Deprecated.
    Record an error.
    void
    error(Throwable error, String description)
    Deprecated.
    Record an error with human readable description.
    void
    error(Throwable error, Map<String,Object> custom)
    Deprecated.
    Record an error with extra information attached.
    void
    error(Throwable error, Map<String,Object> custom, String description)
    Deprecated.
    Record an error with custom parameters and human readable description.
    void
    Deprecated.
    Handle all uncaught errors on current thread with this `Rollbar`.
    void
    Deprecated.
    Handle all uncaught errors on thread with this `Rollbar`.
    void
    info(String message)
    Deprecated.
    Record an informational message.
    void
    info(String message, Map<String,Object> custom)
    Deprecated.
    Record an informational message with extra information attached.
    void
    info(Throwable error)
    Deprecated.
    Record an error as an info.
    void
    info(Throwable error, String description)
    Deprecated.
    Record an info error with human readable description.
    void
    info(Throwable error, Map<String,Object> custom)
    Deprecated.
    Record an info error with extra information attached.
    void
    info(Throwable error, Map<String,Object> custom, String description)
    Deprecated.
    Record an info error with custom parameters and human readable description.
    void
    log(String message)
    Deprecated.
    Record a debugging message at the default level of WARNING.
    void
    log(String message, com.rollbar.api.payload.data.Level level)
    Deprecated.
    Record a message at the level specified.
    void
    log(String message, Map<String,Object> custom)
    Deprecated.
    Record a message with extra information attached at the default level of WARNING.
    void
    log(String message, Map<String,Object> custom, com.rollbar.api.payload.data.Level level)
    Deprecated.
    Record a message with extra information attached at the specified level.
    void
    log(Throwable error)
    Deprecated.
    Log an error at the default level.
    void
    log(Throwable error, com.rollbar.api.payload.data.Level level)
    Deprecated.
    Log an error at level specified.
    void
    log(Throwable error, String description)
    Deprecated.
    Record an error with human readable description at the default level.
    void
    log(Throwable error, String description, com.rollbar.api.payload.data.Level level)
    Deprecated.
    Record a debug error with human readable description at the specified level.
    void
    log(Throwable error, Map<String,Object> custom)
    Deprecated.
    Record an error with extra information attached at the default level.
    void
    log(Throwable error, Map<String,Object> custom, com.rollbar.api.payload.data.Level level)
    Deprecated.
    Record an error with extra information attached at the level specified.
    void
    log(Throwable error, Map<String,Object> custom, String description)
    Deprecated.
    Record an error with custom parameters and human readable description at the default level.
    void
    log(Throwable error, Map<String,Object> custom, String description, com.rollbar.api.payload.data.Level level)
    Deprecated.
    Record an error or message with extra data at the level specified.
    void
    log(Throwable error, Map<String,Object> custom, String description, com.rollbar.api.payload.data.Level level, boolean isUncaught)
    Deprecated.
    Record an error or message with extra data at the level specified.
    void
    warning(String message)
    Deprecated.
    Record a warning message.
    void
    warning(String message, Map<String,Object> custom)
    Deprecated.
    Record a warning message with extra information attached.
    void
    Deprecated.
    Record an error as a warning.
    void
    warning(Throwable error, String description)
    Deprecated.
    Record a warning with human readable description.
    void
    warning(Throwable error, Map<String,Object> custom)
    Deprecated.
    Record a warning error with extra information attached.
    void
    warning(Throwable error, Map<String,Object> custom, String description)
    Deprecated.
    Record a warning error with custom parameters and human readable description.

    Methods inherited from class java.lang.Object

    clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
  • Constructor Details

    • Rollbar

      public Rollbar(String accessToken, String environment)
      Deprecated.
      Construct a notifier defaults for everything including Sender. Caution: default sender is slow and blocking. Consider providing a Sender overload.
      Parameters:
      accessToken - not nullable, the access token to send payloads to
      environment - not nullable, the environment to send payloads under
    • Rollbar

      public Rollbar(String accessToken, String environment, Sender sender)
      Deprecated.
      Construct notifier, defaults for everything but Sender.
      Parameters:
      accessToken - not nullable, the access token to send payloads to
      environment - not nullable, the environment to send payloads under
      sender - the sender to use. If null uses default: Sender
    • Rollbar

      public Rollbar(String accessToken, String environment, Sender sender, String codeVersion, String platform, String language, String framework, String context, com.rollbar.api.payload.data.Request request, com.rollbar.api.payload.data.Person person, com.rollbar.api.payload.data.Server server, Map<String,Object> custom, com.rollbar.api.payload.data.Notifier notifier, SenderListener responseHandler, Filter filter, Transformer transform)
      Deprecated.
      Construct notifier with static values for all configuration options set. Anything left null will use the default value. If appropriate.
      Parameters:
      accessToken - not nullable, the access token to send payloads to
      environment - not nullable, the environment to send payloads under
      sender - the sender to use. If null uses default: Sender
      codeVersion - the version of the code currently running. If code checked out on server: `git rev-parse HEAD`
      platform - the platform you're running. (JVM version, or similar).
      language - the main language you're running ("java" by default, override w/ "clojure", "scala" etc.).
      framework - the framework you're using ("Play", "Spring", etc.).
      context - a mnemonic for finding the code responsible (e.g. controller name, module name)
      request - the HTTP request that triggered this error. Can be set if the IOC container can work per-request.
      person - the affected person. Can be set if the IOC container can work per-request.
      server - info about this server. This can be statically set.
      custom - custom info to send with *every* error. Can be dynamically or statically set.
      notifier - information about this notifier. Default new Notifier() (Notifier.
      responseHandler - what to do with the response. Use this to check for failures and handle some other way.
      filter - filter used to determine if you will send payload. Receives *transformed* payload.
      transform - alter payload before sending.
  • Method Details

    • handleUncaughtErrors

      public void handleUncaughtErrors()
      Deprecated.
      Handle all uncaught errors on current thread with this `Rollbar`.
    • handleUncaughtErrors

      public void handleUncaughtErrors(Thread thread)
      Deprecated.
      Handle all uncaught errors on thread with this `Rollbar`.
      Parameters:
      thread - the thread to handle errors on
    • critical

      public void critical(Throwable error)
      Deprecated.
      Record a critical error.
      Parameters:
      error - the error
    • error

      public void error(Throwable error)
      Deprecated.
      Record an error.
      Parameters:
      error - the error
    • warning

      public void warning(Throwable error)
      Deprecated.
      Record an error as a warning.
      Parameters:
      error - the error
    • info

      public void info(Throwable error)
      Deprecated.
      Record an error as an info.
      Parameters:
      error - the error
    • debug

      public void debug(Throwable error)
      Deprecated.
      Record an error as debugging information.
      Parameters:
      error - the error
    • log

      public void log(Throwable error)
      Deprecated.
      Log an error at the default level.
      Parameters:
      error - the error
    • log

      public void log(Throwable error, com.rollbar.api.payload.data.Level level)
      Deprecated.
      Log an error at level specified.
      Parameters:
      error - the error
      level - the level of the error
    • critical

      public void critical(Throwable error, Map<String,Object> custom)
      Deprecated.
      Record a critical error with extra information attached.
      Parameters:
      error - the error
      custom - the extra information
    • error

      public void error(Throwable error, Map<String,Object> custom)
      Deprecated.
      Record an error with extra information attached.
      Parameters:
      error - the error
      custom - the extra information
    • warning

      public void warning(Throwable error, Map<String,Object> custom)
      Deprecated.
      Record a warning error with extra information attached.
      Parameters:
      error - the error
      custom - the extra information
    • info

      public void info(Throwable error, Map<String,Object> custom)
      Deprecated.
      Record an info error with extra information attached.
      Parameters:
      error - the error
      custom - the extra information
    • debug

      public void debug(Throwable error, Map<String,Object> custom)
      Deprecated.
      Record a debug error with extra information attached.
      Parameters:
      error - the error
      custom - the extra information
    • log

      public void log(Throwable error, Map<String,Object> custom)
      Deprecated.
      Record an error with extra information attached at the default level.
      Parameters:
      error - the error
      custom - the extra information
    • log

      public void log(Throwable error, Map<String,Object> custom, com.rollbar.api.payload.data.Level level)
      Deprecated.
      Record an error with extra information attached at the level specified.
      Parameters:
      error - the error
      custom - the extra information
      level - the level
    • critical

      public void critical(Throwable error, String description)
      Deprecated.
      Record a critical error with human readable description.
      Parameters:
      error - the error
      description - human readable description of error
    • error

      public void error(Throwable error, String description)
      Deprecated.
      Record an error with human readable description.
      Parameters:
      error - the error
      description - human readable description of error
    • warning

      public void warning(Throwable error, String description)
      Deprecated.
      Record a warning with human readable description.
      Parameters:
      error - the error
      description - human readable description of error
    • info

      public void info(Throwable error, String description)
      Deprecated.
      Record an info error with human readable description.
      Parameters:
      error - the error
      description - human readable description of error
    • debug

      public void debug(Throwable error, String description)
      Deprecated.
      Record a debug error with human readable description.
      Parameters:
      error - the error
      description - human readable description of error
    • log

      public void log(Throwable error, String description)
      Deprecated.
      Record an error with human readable description at the default level.
      Parameters:
      error - the error
      description - human readable description of error
    • log

      public void log(Throwable error, String description, com.rollbar.api.payload.data.Level level)
      Deprecated.
      Record a debug error with human readable description at the specified level.
      Parameters:
      error - the error
      description - human readable description of error
      level - the level
    • critical

      public void critical(Throwable error, Map<String,Object> custom, String description)
      Deprecated.
      Record a critical error with custom parameters and human readable description.
      Parameters:
      error - the error
      custom - the custom data
      description - the human readable description of error
    • error

      public void error(Throwable error, Map<String,Object> custom, String description)
      Deprecated.
      Record an error with custom parameters and human readable description.
      Parameters:
      error - the error
      custom - the custom data
      description - the human readable description of error
    • warning

      public void warning(Throwable error, Map<String,Object> custom, String description)
      Deprecated.
      Record a warning error with custom parameters and human readable description.
      Parameters:
      error - the error
      custom - the custom data
      description - the human readable description of error
    • info

      public void info(Throwable error, Map<String,Object> custom, String description)
      Deprecated.
      Record an info error with custom parameters and human readable description.
      Parameters:
      error - the error
      custom - the custom data
      description - the human readable description of error
    • debug

      public void debug(Throwable error, Map<String,Object> custom, String description)
      Deprecated.
      Record a debug error with custom parameters and human readable description.
      Parameters:
      error - the error
      custom - the custom data
      description - the human readable description of error
    • log

      public void log(Throwable error, Map<String,Object> custom, String description)
      Deprecated.
      Record an error with custom parameters and human readable description at the default level.
      Parameters:
      error - the error
      custom - the custom data
      description - the human readable description of error
    • critical

      public void critical(String message)
      Deprecated.
      Record a critical message.
      Parameters:
      message - the message
    • error

      public void error(String message)
      Deprecated.
      Record an error message.
      Parameters:
      message - the message
    • warning

      public void warning(String message)
      Deprecated.
      Record a warning message.
      Parameters:
      message - the message
    • info

      public void info(String message)
      Deprecated.
      Record an informational message.
      Parameters:
      message - the message
    • debug

      public void debug(String message)
      Deprecated.
      Record a debugging message.
      Parameters:
      message - the message
    • log

      public void log(String message)
      Deprecated.
      Record a debugging message at the default level of WARNING.
      Parameters:
      message - the message
    • log

      public void log(String message, com.rollbar.api.payload.data.Level level)
      Deprecated.
      Record a message at the level specified.
      Parameters:
      message - the message
      level - the level
    • critical

      public void critical(String message, Map<String,Object> custom)
      Deprecated.
      Record a critical message with extra information attached.
      Parameters:
      message - the message
      custom - the extra information
    • error

      public void error(String message, Map<String,Object> custom)
      Deprecated.
      Record a error message with extra information attached.
      Parameters:
      message - the message
      custom - the extra information
    • warning

      public void warning(String message, Map<String,Object> custom)
      Deprecated.
      Record a warning message with extra information attached.
      Parameters:
      message - the message
      custom - the extra information
    • info

      public void info(String message, Map<String,Object> custom)
      Deprecated.
      Record an informational message with extra information attached.
      Parameters:
      message - the message
      custom - the extra information
    • debug

      public void debug(String message, Map<String,Object> custom)
      Deprecated.
      Record a debugging message with extra information attached.
      Parameters:
      message - the message
      custom - the extra information
    • log

      public void log(String message, Map<String,Object> custom)
      Deprecated.
      Record a message with extra information attached at the default level of WARNING.
      Parameters:
      message - the message
      custom - the extra information
    • log

      public void log(String message, Map<String,Object> custom, com.rollbar.api.payload.data.Level level)
      Deprecated.
      Record a message with extra information attached at the specified level.
      Parameters:
      message - the message
      custom - the extra information
      level - the level
    • log

      public void log(Throwable error, Map<String,Object> custom, String description, com.rollbar.api.payload.data.Level level)
      Deprecated.
      Record an error or message with extra data at the level specified. At least ene of `error` or `description` must be non-null. If error is null, `description` will be sent as a message. If error is non-null, description will be sent as the description of the error. Custom data will be attached to message if the error is null.
      Parameters:
      error - the error (if any)
      custom - the custom data (if any)
      description - the description of the error, or the message to send
      level - the level to send it at
    • log

      public void log(Throwable error, Map<String,Object> custom, String description, com.rollbar.api.payload.data.Level level, boolean isUncaught)
      Deprecated.
      Record an error or message with extra data at the level specified. At least ene of `error` or `description` must be non-null. If error is null, `description` will be sent as a message. If error is non-null, description will be sent as the description of the error. Custom data will be attached to message if the error is null.
      Parameters:
      error - the error (if any)
      custom - the custom data (if any)
      description - the description of the error, or the message to send
      level - the level to send it at
      isUncaught - whether or not this set of data originates from an uncaught exception.