Class CacheFrame

java.lang.Object
com.rollbar.jvmti.CacheFrame

public final class CacheFrame extends Object
CacheFrame is a frame generated from the native interface to hold a method and a list of local variables for later use.
  • Constructor Details

    • CacheFrame

      public CacheFrame(Method method, LocalVariable[] locals)
      Constructor with the method and list of local variables.
  • Method Details

    • getMethod

      public Method getMethod()
      Getter.
      Returns:
      the method that generated this frame.
    • getLocals

      public Map<String,Object> getLocals()
      Getter.
      Returns:
      the local variables for this frame.
    • toString

      public String toString()
      Overrides:
      toString in class Object