Class LocalVariable

java.lang.Object
com.rollbar.jvmti.LocalVariable

public final class LocalVariable extends Object
LocalVariable is a data object reprsenting a live variable in a stack frame at the time of an exception gathered by the native interface.
  • Constructor Details

    • LocalVariable

      public LocalVariable(String name, Object value)
      Constructor with the variable name and value.
  • Method Details

    • getName

      public String getName()
      Getter.
      Returns:
      the name of the variable.
    • getValue

      public Object getValue()
      Getter.
      Returns:
      the value of the variable.
    • toString

      public String toString()
      Overrides:
      toString in class Object