Interface CommonConfig

All Known Subinterfaces:
Config

public interface CommonConfig
Rollbar notifier settings are common to all types of notifier (sync and async).
  • Method Details

    • accessToken

      String accessToken()
      Get the access token.
      Returns:
      the Rollbar access token.
    • endpoint

      String endpoint()
      Get the Rollbar endpoint.
      Returns:
      the Rollbar endpoint.
    • environment

      String environment()
      Get the environment.
      Returns:
      the environment.
    • codeVersion

      String codeVersion()
      Get the code version.
      Returns:
      the code version.
    • platform

      String platform()
      Get the platform.
      Returns:
      the platform.
    • language

      String language()
      Get the language.
      Returns:
      the language.
    • framework

      String framework()
      Get the framework.
      Returns:
      the framework.
    • context

      Provider<String> context()
      Get the context provider.
      Returns:
      the context.
    • request

      Provider<com.rollbar.api.payload.data.Request> request()
      Get the request provider.
      Returns:
      the request.
    • person

      Provider<com.rollbar.api.payload.data.Person> person()
      Get the person provider.
      Returns:
      the person.
    • server

      Provider<com.rollbar.api.payload.data.Server> server()
      Get the server provider.
      Returns:
      the server.
    • client

      Provider<com.rollbar.api.payload.data.Client> client()
      Get the client provider.
      Returns:
      the server.
    • custom

      Get the custom provider.
      Returns:
      the provider of any custom values.
    • notifier

      Provider<com.rollbar.api.payload.data.Notifier> notifier()
      Get the notifier provider.
      Returns:
      the provider of the notifier data.
    • timestamp

      Provider<Long> timestamp()
      Returns:
      the provider of a timestamp.
    • filter

      Filter filter()
      Get the filter.
      Returns:
      the filter.
    • transformer

      Transformer transformer()
      Get the transformer.
      Returns:
      the transformer.
    • fingerPrintGenerator

      FingerprintGenerator fingerPrintGenerator()
      Returns:
      the fingerprint.
    • uuidGenerator

      UuidGenerator uuidGenerator()
      Returns:
      the uuid generator.
    • jsonSerializer

      JsonSerializer jsonSerializer()
      The serializer to convert a payload to JSON.
      Returns:
      The instance.
    • appPackages

      List<String> appPackages()
      Get the list of packages considered to be in your app.
      Returns:
      the list of packages.
    • handleUncaughtErrors

      boolean handleUncaughtErrors()
      Flag to indicate that the Rollbar notifier should handle the uncaught errors.
      Returns:
      true to handle otherwise false.
    • isEnabled

      boolean isEnabled()
      Flag to indicate that the Rollbar notifier should be enabled/disabled.
      Returns:
      true if enabled otherwise false.
    • defaultMessageLevel

      com.rollbar.api.payload.data.Level defaultMessageLevel()
      Level to use as the default for messages if one is not otherwise specified.
      Returns:
      the level.
    • defaultErrorLevel

      com.rollbar.api.payload.data.Level defaultErrorLevel()
      Level to use as the default for Errors if one is not otherwise specified.
      Returns:
      the level.
    • defaultThrowableLevel

      com.rollbar.api.payload.data.Level defaultThrowableLevel()
      Level to use as the default for non-Error Throwables if one is not otherwise specified.
      Returns:
      the level.
    • truncateLargePayloads

      boolean truncateLargePayloads()

      If set to true, the notifier will attempt to truncate payloads that are larger than the maximum size Rollbar allows. Default: false.

      Returns:
      true to truncate payloads otherwise false.
    • maximumTelemetryData

      int maximumTelemetryData()
    • telemetryEventTracker

      TelemetryEventTracker telemetryEventTracker()