Package com.rollbar.notifier.wrapper
Class RollbarThrowableWrapper
java.lang.Object
com.rollbar.notifier.wrapper.RollbarThrowableWrapper
- All Implemented Interfaces:
ThrowableWrapper
Implementation of the
throwable wrapper.-
Constructor Summary
ConstructorsConstructorDescriptionRollbarThrowableWrapper(String className, String message, StackTraceElement[] stackTraceElements, ThrowableWrapper cause) Constructor.RollbarThrowableWrapper(Throwable throwable) Constructor.RollbarThrowableWrapper(Throwable throwable, Thread thread) Constructor.RollbarThrowableWrapper(Throwable throwable, List<com.rollbar.api.payload.data.body.RollbarThread> rollbarThreads) Constructor. -
Method Summary
Modifier and TypeMethodDescriptionbooleanGet a map of stack traces for all live threads in the moment of the Exception.getCause()Get thethrowable wrappedcause.Get thethrowableclass name.Get thethrowablemessage.com.rollbar.api.payload.data.body.RollbarThreadGet the RollbarThreadrollbarThread.List<com.rollbar.api.payload.data.body.RollbarThread>Get a list of the RollbarThreads for this error.Get thethrowablestack trace elements.Get the wrappedthrowable.inthashCode()toString()
-
Constructor Details
-
RollbarThrowableWrapper
Constructor.- Parameters:
throwable- the throwable.
-
RollbarThrowableWrapper
Constructor.- Parameters:
throwable- the throwable.
-
RollbarThrowableWrapper
public RollbarThrowableWrapper(Throwable throwable, List<com.rollbar.api.payload.data.body.RollbarThread> rollbarThreads) Constructor.- Parameters:
throwable- the throwable.
-
RollbarThrowableWrapper
public RollbarThrowableWrapper(String className, String message, StackTraceElement[] stackTraceElements, ThrowableWrapper cause) Constructor.- Parameters:
className- the class name.message- the message.stackTraceElements- the stack trace elements.cause- the cause.
-
-
Method Details
-
getClassName
Description copied from interface:ThrowableWrapperGet thethrowableclass name.- Specified by:
getClassNamein interfaceThrowableWrapper- Returns:
- the class name.
-
getMessage
Description copied from interface:ThrowableWrapperGet thethrowablemessage.- Specified by:
getMessagein interfaceThrowableWrapper- Returns:
- the message.
-
getStackTrace
Description copied from interface:ThrowableWrapperGet thethrowablestack trace elements.- Specified by:
getStackTracein interfaceThrowableWrapper- Returns:
- the stack trace elements.
-
getCause
Description copied from interface:ThrowableWrapperGet thethrowable wrappedcause.- Specified by:
getCausein interfaceThrowableWrapper- Returns:
- the cause.
-
getThrowable
Description copied from interface:ThrowableWrapperGet the wrappedthrowable.- Specified by:
getThrowablein interfaceThrowableWrapper- Returns:
- the throwable.
-
getRollbarThread
public com.rollbar.api.payload.data.body.RollbarThread getRollbarThread()Description copied from interface:ThrowableWrapperGet the RollbarThreadrollbarThread.- Specified by:
getRollbarThreadin interfaceThrowableWrapper- Returns:
- the rollbarThread.
-
getAllStackTraces
Description copied from interface:ThrowableWrapperGet a map of stack traces for all live threads in the moment of the Exception.- Specified by:
getAllStackTracesin interfaceThrowableWrapper- Returns:
- the map.
-
getRollbarThreads
Description copied from interface:ThrowableWrapperGet a list of the RollbarThreads for this error.- Specified by:
getRollbarThreadsin interfaceThrowableWrapper- Returns:
- the RollbarThreads.
-
toString
-
equals
-
hashCode
public int hashCode()
-