Interface ThrowableWrapper

All Known Implementing Classes:
RollbarThrowableWrapper

public interface ThrowableWrapper
Throwable wrapper to wrap a thowable or to represent a not available one.
  • Method Details

    • getClassName

      String getClassName()
      Get the throwable class name.
      Returns:
      the class name.
    • getMessage

      String getMessage()
      Get the throwable message.
      Returns:
      the message.
    • getStackTrace

      StackTraceElement[] getStackTrace()
      Get the throwable stack trace elements.
      Returns:
      the stack trace elements.
    • getCause

      ThrowableWrapper getCause()
      Get the throwable wrapped cause.
      Returns:
      the cause.
    • getThrowable

      Throwable getThrowable()
      Get the wrapped throwable.
      Returns:
      the throwable.
    • getRollbarThread

      com.rollbar.api.payload.data.body.RollbarThread getRollbarThread()
      Get the RollbarThread rollbarThread.
      Returns:
      the rollbarThread.
    • getAllStackTraces

      Map<Thread,StackTraceElement[]> getAllStackTraces()
      Get a map of stack traces for all live threads in the moment of the Exception.
      Returns:
      the map.
    • getRollbarThreads

      List<com.rollbar.api.payload.data.body.RollbarThread> getRollbarThreads()
      Get a list of the RollbarThreads for this error.
      Returns:
      the RollbarThreads.