Index
All Classes and Interfaces|All Packages|Constant Field Values|Serialized Form
A
- AbstractSender - Class in com.rollbar.notifier.sender
-
Base class to implement
senders.Implementations based on this class should just implement theAbstractSender.doSend(com.rollbar.api.payload.Payload)method and not have to deal with listener and notifications to them. - AbstractSender() - Constructor for class com.rollbar.notifier.sender.AbstractSender
- accessToken - Variable in class com.rollbar.notifier.config.ConfigBuilder
- accessToken() - Method in interface com.rollbar.notifier.config.CommonConfig
-
Get the access token.
- accessToken(String) - Method in class com.rollbar.notifier.config.ConfigBuilder
-
The access token to use.
- accessToken(String) - Method in class com.rollbar.notifier.sender.SyncSender.Builder
-
The rollbar access token.
- add(Throwable, CacheFrame[]) - Static method in class com.rollbar.jvmti.ThrowableCache
-
Add a list of frames with extra information to the cache associated to this particular throwable.
- addAppPackage(String) - Static method in class com.rollbar.jvmti.ThrowableCache
-
Add a string representing a package prefix to check against class names in stack traces to determine whether to cache throwables or not.
- addListener(SenderListener) - Method in class com.rollbar.notifier.sender.AbstractSender
- addListener(SenderListener) - Method in class com.rollbar.notifier.sender.BufferedSender
- addListener(SenderListener) - Method in class com.rollbar.notifier.sender.listener.SenderListenerCollection
- addListener(SenderListener) - Method in interface com.rollbar.notifier.sender.Sender
-
Registers a listener to get notifications of sending payloads through the
sender listener. - ApiException - Exception in com.rollbar.notifier.sender.exception
-
Represents an error return by the Rollbar API.
- ApiException(Response) - Constructor for exception com.rollbar.notifier.sender.exception.ApiException
-
Constructor.
- appPackages - Variable in class com.rollbar.notifier.config.ConfigBuilder
- appPackages() - Method in interface com.rollbar.notifier.config.CommonConfig
-
Get the list of packages considered to be in your app.
- appPackages(List<String>) - Method in class com.rollbar.notifier.config.ConfigBuilder
-
The list of packages to be considered in your app.
B
- batchSize(int) - Method in class com.rollbar.notifier.sender.BufferedSender.Builder
-
The batch size for every flush.
- body(String) - Method in class com.rollbar.notifier.sender.result.Result.Builder
-
The body of the response returned by Rollbar.
- bodyFactory - Variable in class com.rollbar.notifier.RollbarBase
- BodyFactory - Class in com.rollbar.notifier.util
-
Body factory helper to build the proper body depending on the throwable or the description.
- BodyFactory() - Constructor for class com.rollbar.notifier.util.BodyFactory
- BufferedSender - Class in com.rollbar.notifier.sender
-
A buffered sender implementation.
- BufferedSender.Builder - Class in com.rollbar.notifier.sender
-
Builder class for
BufferedSender. - build() - Method in class com.rollbar.notifier.config.ConfigBuilder
-
Builds the
config. - build() - Method in class com.rollbar.notifier.sender.BufferedSender.Builder
-
Builds the
buffered sender. - build() - Method in class com.rollbar.notifier.sender.queue.DiskQueue.Builder
-
Builds the
disk queue. - build() - Method in class com.rollbar.notifier.sender.result.Response.Builder
-
Builds the
response. - build() - Method in class com.rollbar.notifier.sender.result.Result.Builder
-
Builds the
result. - build() - Method in class com.rollbar.notifier.sender.SyncSender.Builder
-
Builds the
sync sender. - buildData(CommonConfig, ThrowableWrapper, Map<String, Object>, String, Level, boolean) - Method in class com.rollbar.notifier.RollbarBase
- Builder() - Constructor for class com.rollbar.notifier.sender.BufferedSender.Builder
-
Constructor.
- Builder() - Constructor for class com.rollbar.notifier.sender.queue.DiskQueue.Builder
-
Constructor.
- Builder() - Constructor for class com.rollbar.notifier.sender.result.Response.Builder
- Builder() - Constructor for class com.rollbar.notifier.sender.result.Result.Builder
- Builder() - Constructor for class com.rollbar.notifier.sender.SyncSender.Builder
- Builder(String) - Constructor for class com.rollbar.notifier.sender.SyncSender.Builder
-
Constructor.
C
- CacheFrame - Class in com.rollbar.jvmti
-
CacheFrame is a frame generated from the native interface to hold a method and a list of local variables for later use.
- CacheFrame(Method, LocalVariable[]) - Constructor for class com.rollbar.jvmti.CacheFrame
-
Constructor with the method and list of local variables.
- CAN_BE_RETRIED - Enum constant in enum class com.rollbar.notifier.sender.SenderFailureStrategy.PayloadAction
-
Sending the occurrence wasn't successful for a reason that warrants a retry (eg.
- client - Variable in class com.rollbar.notifier.config.ConfigBuilder
- client() - Method in interface com.rollbar.notifier.config.CommonConfig
-
Get the
clientprovider. - client(Provider<Client>) - Method in class com.rollbar.notifier.config.ConfigBuilder
-
The provider to retrieve the
client. - close() - Method in class com.rollbar.notifier.sender.AbstractSender
- close() - Method in class com.rollbar.notifier.sender.BufferedSender
- close() - Method in class com.rollbar.notifier.sender.SyncSender
- close(boolean) - Method in class com.rollbar.notifier.Rollbar
- close(boolean) - Method in class com.rollbar.notifier.sender.AbstractSender
- close(boolean) - Method in class com.rollbar.notifier.sender.BufferedSender
- close(boolean) - Method in interface com.rollbar.notifier.sender.Sender
-
Closes the sender.
- close(Closeable) - Static method in class com.rollbar.notifier.util.ObjectsUtils
-
Closes stream if possible.
- code(int) - Method in class com.rollbar.notifier.sender.result.Result.Builder
-
The err returned by Rollbar.
- codeVersion - Variable in class com.rollbar.notifier.config.ConfigBuilder
- codeVersion() - Method in interface com.rollbar.notifier.config.CommonConfig
-
Get the code version.
- codeVersion(String) - Method in class com.rollbar.notifier.config.ConfigBuilder
-
The currently running version of the code.
- com.rollbar - package com.rollbar
- com.rollbar.jvmti - package com.rollbar.jvmti
- com.rollbar.notifier - package com.rollbar.notifier
- com.rollbar.notifier.config - package com.rollbar.notifier.config
- com.rollbar.notifier.filter - package com.rollbar.notifier.filter
- com.rollbar.notifier.fingerprint - package com.rollbar.notifier.fingerprint
- com.rollbar.notifier.provider - package com.rollbar.notifier.provider
- com.rollbar.notifier.provider.notifier - package com.rollbar.notifier.provider.notifier
- com.rollbar.notifier.provider.server - package com.rollbar.notifier.provider.server
- com.rollbar.notifier.provider.timestamp - package com.rollbar.notifier.provider.timestamp
- com.rollbar.notifier.sender - package com.rollbar.notifier.sender
- com.rollbar.notifier.sender.exception - package com.rollbar.notifier.sender.exception
- com.rollbar.notifier.sender.json - package com.rollbar.notifier.sender.json
- com.rollbar.notifier.sender.listener - package com.rollbar.notifier.sender.listener
- com.rollbar.notifier.sender.queue - package com.rollbar.notifier.sender.queue
- com.rollbar.notifier.sender.result - package com.rollbar.notifier.sender.result
- com.rollbar.notifier.telemetry - package com.rollbar.notifier.telemetry
- com.rollbar.notifier.transformer - package com.rollbar.notifier.transformer
- com.rollbar.notifier.truncation - package com.rollbar.notifier.truncation
- com.rollbar.notifier.uncaughtexception - package com.rollbar.notifier.uncaughtexception
- com.rollbar.notifier.util - package com.rollbar.notifier.util
- com.rollbar.notifier.uuid - package com.rollbar.notifier.uuid
- com.rollbar.notifier.wrapper - package com.rollbar.notifier.wrapper
- CommonConfig - Interface in com.rollbar.notifier.config
-
Rollbar notifier settings are common to all types of notifier (sync and async).
- config - Variable in class com.rollbar.notifier.RollbarBase
- config() - Method in class com.rollbar.notifier.Rollbar
-
Get the current config.
- Config - Interface in com.rollbar.notifier.config
-
The configuration for the
notifier. - ConfigBuilder - Class in com.rollbar.notifier.config
-
Configuration builder to build the
configurationof therollbarnotifier. - ConfigBuilder(String) - Constructor for class com.rollbar.notifier.config.ConfigBuilder
-
Constructor with an access token.
- ConfigProvider - Interface in com.rollbar.notifier.config
- ConfigProviderHelper - Class in com.rollbar.notifier.config
-
Static helper for the ConfigProvider class.
- ConfigProviderHelper() - Constructor for class com.rollbar.notifier.config.ConfigProviderHelper
- configReadLock - Variable in class com.rollbar.notifier.RollbarBase
- configReadWriteLock - Variable in class com.rollbar.notifier.RollbarBase
- configure(C) - Method in class com.rollbar.notifier.RollbarBase
-
Replace the configuration of this instance directly.
- configure(Config) - Method in class com.rollbar.notifier.Rollbar
-
Replace the configuration of this instance directly.
- configure(ConfigProvider) - Method in class com.rollbar.notifier.Rollbar
-
Replace the configuration of this instance.
- configWriteLock - Variable in class com.rollbar.notifier.RollbarBase
- context - Variable in class com.rollbar.notifier.config.ConfigBuilder
- context() - Method in interface com.rollbar.notifier.config.CommonConfig
-
Get the context provider.
- context(Provider<String>) - Method in class com.rollbar.notifier.config.ConfigBuilder
-
The provider to retrieve the context.
- critical(String) - Method in class com.rollbar.notifier.Rollbar
-
Record a critical message.
- critical(String) - Method in class com.rollbar.Rollbar
-
Deprecated.Record a critical message.
- critical(String, Map<String, Object>) - Method in class com.rollbar.notifier.Rollbar
-
Record a critical message with custom data attached.
- critical(String, Map<String, Object>) - Method in class com.rollbar.Rollbar
-
Deprecated.Record a critical message with extra information attached.
- critical(Throwable) - Method in class com.rollbar.notifier.Rollbar
-
Record a critical error.
- critical(Throwable) - Method in class com.rollbar.Rollbar
-
Deprecated.Record a critical error.
- critical(Throwable, String) - Method in class com.rollbar.notifier.Rollbar
-
Record a critical error with human readable description.
- critical(Throwable, String) - Method in class com.rollbar.Rollbar
-
Deprecated.Record a critical error with human readable description.
- critical(Throwable, Map<String, Object>) - Method in class com.rollbar.notifier.Rollbar
-
Record a critical error with custom data attached.
- critical(Throwable, Map<String, Object>) - Method in class com.rollbar.Rollbar
-
Deprecated.Record a critical error with extra information attached.
- critical(Throwable, Map<String, Object>, String) - Method in class com.rollbar.notifier.Rollbar
-
Record a critical error with custom data and human readable description.
- critical(Throwable, Map<String, Object>, String) - Method in class com.rollbar.Rollbar
-
Deprecated.Record a critical error with custom parameters and human readable description.
- custom - Variable in class com.rollbar.notifier.config.ConfigBuilder
- custom() - Method in interface com.rollbar.notifier.config.CommonConfig
-
Get the custom
provider. - custom(Provider<Map<String, Object>>) - Method in class com.rollbar.notifier.config.ConfigBuilder
-
The provider to retrieve the custom.
D
- debug(String) - Method in class com.rollbar.notifier.Rollbar
-
Record a debugging message.
- debug(String) - Method in class com.rollbar.Rollbar
-
Deprecated.Record a debugging message.
- debug(String, Map<String, Object>) - Method in class com.rollbar.notifier.Rollbar
-
Record a debugging message with custom data attached.
- debug(String, Map<String, Object>) - Method in class com.rollbar.Rollbar
-
Deprecated.Record a debugging message with extra information attached.
- debug(Throwable) - Method in class com.rollbar.notifier.Rollbar
-
Record an error as debugging information.
- debug(Throwable) - Method in class com.rollbar.Rollbar
-
Deprecated.Record an error as debugging information.
- debug(Throwable, String) - Method in class com.rollbar.notifier.Rollbar
-
Record a debug error with human readable description.
- debug(Throwable, String) - Method in class com.rollbar.Rollbar
-
Deprecated.Record a debug error with human readable description.
- debug(Throwable, Map<String, Object>) - Method in class com.rollbar.notifier.Rollbar
-
Record a debug error with custom data attached.
- debug(Throwable, Map<String, Object>) - Method in class com.rollbar.Rollbar
-
Deprecated.Record a debug error with extra information attached.
- debug(Throwable, Map<String, Object>, String) - Method in class com.rollbar.notifier.Rollbar
-
Record a debug error with custom data and human readable description.
- debug(Throwable, Map<String, Object>, String) - Method in class com.rollbar.Rollbar
-
Deprecated.Record a debug error with custom parameters and human readable description.
- DEFAULT_API_ENDPOINT - Static variable in class com.rollbar.notifier.sender.SyncSender
- defaultErrorLevel() - Method in interface com.rollbar.notifier.config.CommonConfig
-
Level to use as the default for Errors if one is not otherwise specified.
- defaultErrorLevel(Level) - Method in class com.rollbar.notifier.config.ConfigBuilder
-
Level to use as the default for Errors if one is not otherwise specified.
- defaultLevels - Variable in class com.rollbar.notifier.config.ConfigBuilder
- DefaultLevels - Class in com.rollbar.notifier.config
-
Holds the default level configuration for ocurrence reporting of different types.
- DefaultLevels() - Constructor for class com.rollbar.notifier.config.DefaultLevels
-
Initialises all levels to their defaults.
- DefaultLevels(CommonConfig) - Constructor for class com.rollbar.notifier.config.DefaultLevels
-
Initialises all levels based on an existing config.
- defaultMessageLevel() - Method in interface com.rollbar.notifier.config.CommonConfig
-
Level to use as the default for messages if one is not otherwise specified.
- defaultMessageLevel(Level) - Method in class com.rollbar.notifier.config.ConfigBuilder
-
Level to use as the default for messages if one is not otherwise specified.
- defaultThrowableLevel() - Method in interface com.rollbar.notifier.config.CommonConfig
-
Level to use as the default for non-Error Throwables if one is not otherwise specified.
- defaultThrowableLevel(Level) - Method in class com.rollbar.notifier.config.ConfigBuilder
-
Level to use as the default for non-Error Throwables if one is not otherwise specified.
- DiskQueue - Class in com.rollbar.notifier.sender.queue
-
A
queueofpayloadspersisted on disk. - DiskQueue.Builder - Class in com.rollbar.notifier.sender.queue
-
Builder class for
DiskQueue. - doSend(Payload) - Method in class com.rollbar.notifier.sender.AbstractSender
-
This method just do the send logic.
- doSend(Payload) - Method in class com.rollbar.notifier.sender.SyncSender
E
- enabled - Variable in class com.rollbar.notifier.config.ConfigBuilder
- enabled(boolean) - Method in class com.rollbar.notifier.config.ConfigBuilder
-
Flag to indicate that the Rollbar notifier should enabled/disabled.
- endpoint - Variable in class com.rollbar.notifier.config.ConfigBuilder
- endpoint() - Method in interface com.rollbar.notifier.config.CommonConfig
-
Get the Rollbar endpoint.
- endpoint(String) - Method in class com.rollbar.notifier.config.ConfigBuilder
-
The Rollbar endpoint to use.
- environment - Variable in class com.rollbar.notifier.config.ConfigBuilder
- environment() - Method in interface com.rollbar.notifier.config.CommonConfig
-
Get the environment.
- environment(String) - Method in class com.rollbar.notifier.config.ConfigBuilder
-
Represents the current environment (e.g.: production, debug, test).
- equals(Object) - Method in exception com.rollbar.notifier.sender.exception.ApiException
- equals(Object) - Method in class com.rollbar.notifier.sender.result.Response
- equals(Object) - Method in class com.rollbar.notifier.sender.result.Result
- equals(Object) - Method in class com.rollbar.notifier.wrapper.RollbarThrowableWrapper
- equals(Object, Object) - Static method in class com.rollbar.notifier.util.ObjectsUtils
- error(String) - Method in class com.rollbar.notifier.Rollbar
-
Record an error message.
- error(String) - Method in class com.rollbar.Rollbar
-
Deprecated.Record an error message.
- error(String, Map<String, Object>) - Method in class com.rollbar.notifier.Rollbar
-
Record a error message with custom data attached.
- error(String, Map<String, Object>) - Method in class com.rollbar.Rollbar
-
Deprecated.Record a error message with extra information attached.
- error(Throwable) - Method in class com.rollbar.notifier.Rollbar
-
Record an error.
- error(Throwable) - Method in class com.rollbar.Rollbar
-
Deprecated.Record an error.
- error(Throwable, String) - Method in class com.rollbar.notifier.Rollbar
-
Record an error with human readable description.
- error(Throwable, String) - Method in class com.rollbar.Rollbar
-
Deprecated.Record an error with human readable description.
- error(Throwable, Map<String, Object>) - Method in class com.rollbar.notifier.Rollbar
-
Record an error with custom data attached.
- error(Throwable, Map<String, Object>) - Method in class com.rollbar.Rollbar
-
Deprecated.Record an error with extra information attached.
- error(Throwable, Map<String, Object>, String) - Method in class com.rollbar.notifier.Rollbar
-
Record an error with custom data and human readable description.
- error(Throwable, Map<String, Object>, String) - Method in class com.rollbar.Rollbar
-
Deprecated.Record an error with custom parameters and human readable description.
F
- filter - Variable in class com.rollbar.notifier.config.ConfigBuilder
- filter() - Method in interface com.rollbar.notifier.config.CommonConfig
-
Get the
filter. - filter(Filter) - Method in class com.rollbar.notifier.config.ConfigBuilder
-
The provider to retrieve the
filter. - Filter - Interface in com.rollbar.notifier.filter
-
Filter interface.
- FilterPipeline - Class in com.rollbar.notifier.filter
- FilterPipeline() - Constructor for class com.rollbar.notifier.filter.FilterPipeline
-
Constructor.
- FilterPipeline(List<Filter>) - Constructor for class com.rollbar.notifier.filter.FilterPipeline
-
Constructor.
- finalSize - Variable in class com.rollbar.notifier.truncation.PayloadTruncator.PayloadTruncationResult
- fingerPrintGenerator - Variable in class com.rollbar.notifier.config.ConfigBuilder
- fingerPrintGenerator() - Method in interface com.rollbar.notifier.config.CommonConfig
-
Get the
fingerprint generator. - fingerPrintGenerator(FingerprintGenerator) - Method in class com.rollbar.notifier.config.ConfigBuilder
-
The provider to retrieve the
fingerprint generator. - FingerprintGenerator - Interface in com.rollbar.notifier.fingerprint
-
Interface to generate the fingerprint of the
datato send to Rollbar. - flushFreq(long) - Method in class com.rollbar.notifier.sender.BufferedSender.Builder
-
The frequency to flush the queue in millis.
- framework - Variable in class com.rollbar.notifier.config.ConfigBuilder
- framework() - Method in interface com.rollbar.notifier.config.CommonConfig
-
Get the framework.
- framework(String) - Method in class com.rollbar.notifier.config.ConfigBuilder
-
The framework being run (e.g.
- from(Data) - Method in interface com.rollbar.notifier.fingerprint.FingerprintGenerator
-
Generates the fingerprint for the data.
- from(Data) - Method in interface com.rollbar.notifier.uuid.UuidGenerator
-
Generates the UUID for the data.
- from(ThrowableWrapper, String) - Method in class com.rollbar.notifier.util.BodyFactory
-
Builds the body from the
throwableWrapperand the description supplied. - from(ThrowableWrapper, String, List<TelemetryEvent>) - Method in class com.rollbar.notifier.util.BodyFactory
-
Builds the body from the
throwableWrapper, the description supplied and telemetry events. - from(StackTraceElement[]) - Method in class com.rollbar.notifier.util.BodyFactory
-
Builds a Group from an Array of StackTraceElement.
- from(Thread) - Method in class com.rollbar.notifier.util.BodyFactory
-
Builds a RollbarThread from a Thread.
- from(Throwable, String) - Method in class com.rollbar.notifier.util.BodyFactory
-
Deprecated.
G
- get(Throwable) - Static method in class com.rollbar.jvmti.ThrowableCache
-
Get the cached frames associated with the given throwable.
- getAction(Payload, Response) - Method in interface com.rollbar.notifier.sender.SenderFailureStrategy
-
Get the action to perform after the payload has been sent.
- getAction(Payload, Exception) - Method in interface com.rollbar.notifier.sender.SenderFailureStrategy
-
Get the action to perform after the error.
- getAll() - Method in class com.rollbar.notifier.telemetry.RollbarTelemetryEventTracker
- getAll() - Method in interface com.rollbar.notifier.telemetry.TelemetryEventTracker
-
Get all the events recorded.
- getAllStackTraces() - Method in class com.rollbar.notifier.wrapper.RollbarThrowableWrapper
- getAllStackTraces() - Method in interface com.rollbar.notifier.wrapper.ThrowableWrapper
-
Get a map of stack traces for all live threads in the moment of the Exception.
- getCause() - Method in class com.rollbar.notifier.wrapper.RollbarThrowableWrapper
- getCause() - Method in interface com.rollbar.notifier.wrapper.ThrowableWrapper
-
Get the
throwable wrappedcause. - getClassName() - Method in class com.rollbar.notifier.wrapper.RollbarThrowableWrapper
- getClassName() - Method in interface com.rollbar.notifier.wrapper.ThrowableWrapper
-
Get the
throwableclass name. - getConfigProvider(String) - Static method in class com.rollbar.notifier.config.ConfigProviderHelper
-
Instantiate a ConfigProvider object based on the class name given as parameter.
- getContent() - Method in class com.rollbar.notifier.sender.result.Result
-
The content return by Rollbar, message/uuid.
- getErr() - Method in class com.rollbar.notifier.sender.result.Result
-
The err field of the json returned by Rollbar.
- getError() - Method in class com.rollbar.notifier.config.DefaultLevels
- getListeners() - Method in class com.rollbar.notifier.sender.AbstractSender
- getListeners() - Method in class com.rollbar.notifier.sender.BufferedSender
- getListeners() - Method in class com.rollbar.notifier.sender.listener.SenderListenerCollection
- getListeners() - Method in interface com.rollbar.notifier.sender.Sender
-
Get the list of listeners registered.
- getLocals() - Method in class com.rollbar.jvmti.CacheFrame
-
Getter.
- getMessage() - Method in class com.rollbar.notifier.config.DefaultLevels
- getMessage() - Method in class com.rollbar.notifier.wrapper.RollbarThrowableWrapper
- getMessage() - Method in interface com.rollbar.notifier.wrapper.ThrowableWrapper
-
Get the
throwablemessage. - getMethod() - Method in class com.rollbar.jvmti.CacheFrame
-
Getter.
- getName() - Method in class com.rollbar.jvmti.LocalVariable
-
Getter.
- getPayload() - Method in class com.rollbar.notifier.truncation.PayloadTruncator.PayloadTruncationResult
- getResult() - Method in class com.rollbar.notifier.sender.result.Response
-
The Rollbar result from API.
- getRollbarThread() - Method in class com.rollbar.notifier.wrapper.RollbarThrowableWrapper
- getRollbarThread() - Method in interface com.rollbar.notifier.wrapper.ThrowableWrapper
-
Get the RollbarThread
rollbarThread. - getRollbarThreads() - Method in class com.rollbar.notifier.wrapper.RollbarThrowableWrapper
- getRollbarThreads() - Method in interface com.rollbar.notifier.wrapper.ThrowableWrapper
-
Get a list of the RollbarThreads for this error.
- getStackTrace() - Method in class com.rollbar.notifier.wrapper.RollbarThrowableWrapper
- getStackTrace() - Method in interface com.rollbar.notifier.wrapper.ThrowableWrapper
-
Get the
throwablestack trace elements. - getStatus() - Method in class com.rollbar.notifier.sender.result.Response
-
The status code of the response.
- getTelemetryEventTracker() - Method in class com.rollbar.notifier.RollbarBase
-
Gives the current TelemetryEventTracker.
- getThrowable() - Method in class com.rollbar.notifier.config.DefaultLevels
- getThrowable() - Method in class com.rollbar.notifier.wrapper.RollbarThrowableWrapper
- getThrowable() - Method in interface com.rollbar.notifier.wrapper.ThrowableWrapper
-
Get the wrapped
throwable. - getValue() - Method in class com.rollbar.jvmti.LocalVariable
-
Getter.
H
- handleUncaughtErrors - Variable in class com.rollbar.notifier.config.ConfigBuilder
- handleUncaughtErrors() - Method in interface com.rollbar.notifier.config.CommonConfig
-
Flag to indicate that the Rollbar notifier should handle the uncaught errors.
- handleUncaughtErrors() - Method in class com.rollbar.notifier.Rollbar
-
Handle all uncaught errors on current thread with this `Rollbar`.
- handleUncaughtErrors() - Method in class com.rollbar.Rollbar
-
Deprecated.Handle all uncaught errors on current thread with this `Rollbar`.
- handleUncaughtErrors(boolean) - Method in class com.rollbar.notifier.config.ConfigBuilder
-
Flag to set the default handler for uncaught errors, see
Thread.UncaughtExceptionHandler. - handleUncaughtErrors(Thread) - Method in class com.rollbar.notifier.Rollbar
-
Handle all uncaught errors on
threadwith this `Rollbar`. - handleUncaughtErrors(Thread) - Method in class com.rollbar.Rollbar
-
Deprecated.Handle all uncaught errors on
threadwith this `Rollbar`. - hash(Object...) - Static method in class com.rollbar.notifier.util.ObjectsUtils
- hashCode() - Method in exception com.rollbar.notifier.sender.exception.ApiException
- hashCode() - Method in class com.rollbar.notifier.sender.result.Response
- hashCode() - Method in class com.rollbar.notifier.sender.result.Result
- hashCode() - Method in class com.rollbar.notifier.wrapper.RollbarThrowableWrapper
I
- info(String) - Method in class com.rollbar.notifier.Rollbar
-
Record an informational message.
- info(String) - Method in class com.rollbar.Rollbar
-
Deprecated.Record an informational message.
- info(String, Map<String, Object>) - Method in class com.rollbar.notifier.Rollbar
-
Record an informational message with custom data attached.
- info(String, Map<String, Object>) - Method in class com.rollbar.Rollbar
-
Deprecated.Record an informational message with extra information attached.
- info(Throwable) - Method in class com.rollbar.notifier.Rollbar
-
Record an error as an info.
- info(Throwable) - Method in class com.rollbar.Rollbar
-
Deprecated.Record an error as an info.
- info(Throwable, String) - Method in class com.rollbar.notifier.Rollbar
-
Record an info error with human readable description.
- info(Throwable, String) - Method in class com.rollbar.Rollbar
-
Deprecated.Record an info error with human readable description.
- info(Throwable, Map<String, Object>) - Method in class com.rollbar.notifier.Rollbar
-
Record an info error with custom data attached.
- info(Throwable, Map<String, Object>) - Method in class com.rollbar.Rollbar
-
Deprecated.Record an info error with extra information attached.
- info(Throwable, Map<String, Object>, String) - Method in class com.rollbar.notifier.Rollbar
-
Record an info error with custom data and human readable description.
- info(Throwable, Map<String, Object>, String) - Method in class com.rollbar.Rollbar
-
Deprecated.Record an info error with custom parameters and human readable description.
- init(Config) - Static method in class com.rollbar.notifier.Rollbar
-
Method to initialize the library managed notifier instance.
- initialFlushDelay(long) - Method in class com.rollbar.notifier.sender.BufferedSender.Builder
-
The frequency to wait before the first flush of the queue in millis.
- isEnabled() - Method in interface com.rollbar.notifier.config.CommonConfig
-
Flag to indicate that the Rollbar notifier should be enabled/disabled.
- isError() - Method in class com.rollbar.notifier.sender.result.Result
-
Indicates if is an error.
- isSendingSuspended() - Method in interface com.rollbar.notifier.sender.SenderFailureStrategy
-
Is sending of occurrences currently suspended.
- iterator() - Method in class com.rollbar.notifier.sender.queue.DiskQueue
J
- jsonSerializer - Variable in class com.rollbar.notifier.config.ConfigBuilder
- jsonSerializer() - Method in interface com.rollbar.notifier.config.CommonConfig
-
The serializer to convert a payload to JSON.
- jsonSerializer(JsonSerializer) - Method in class com.rollbar.notifier.config.ConfigBuilder
-
The JsonSerializer to use with the default Sender if no other sender is specified.
- jsonSerializer(JsonSerializer) - Method in class com.rollbar.notifier.sender.SyncSender.Builder
-
The
json serializer. - JsonSerializer - Interface in com.rollbar.notifier.sender.json
-
Serializer to be used by the
sender. - JsonSerializerImpl - Class in com.rollbar.notifier.sender.json
-
Implementation of the
json serializer. - JsonSerializerImpl() - Constructor for class com.rollbar.notifier.sender.json.JsonSerializerImpl
-
Construct a JsonSerializerImpl that does not pretty print the Payload.
- JsonSerializerImpl(boolean) - Constructor for class com.rollbar.notifier.sender.json.JsonSerializerImpl
-
Construct a JsonSerializerImpl.
L
- language - Variable in class com.rollbar.notifier.config.ConfigBuilder
- language() - Method in interface com.rollbar.notifier.config.CommonConfig
-
Get the language.
- language(String) - Method in class com.rollbar.notifier.config.ConfigBuilder
-
The language running (most likely java, but any JVM language might be here).
- level(CommonConfig, Throwable) - Method in class com.rollbar.notifier.RollbarBase
-
Get the level of the error or message.
- level(Config, Throwable) - Method in class com.rollbar.notifier.Rollbar
-
Get the level of the error or message.
- LocalVariable - Class in com.rollbar.jvmti
-
LocalVariable is a data object reprsenting a live variable in a stack frame at the time of an exception gathered by the native interface.
- LocalVariable(String, Object) - Constructor for class com.rollbar.jvmti.LocalVariable
-
Constructor with the variable name and value.
- log(ThrowableWrapper) - Method in class com.rollbar.notifier.Rollbar
-
Record an error or message with extra data at the level specified.
- log(ThrowableWrapper, Map<String, Object>, String, Level, boolean) - Method in class com.rollbar.notifier.Rollbar
-
Record an error or message with extra data at the level specified.
- log(String) - Method in class com.rollbar.notifier.Rollbar
-
Record a debugging message at the level returned by
Rollbar.level(com.rollbar.notifier.config.Config, java.lang.Throwable)(WARNING unless level is overridden). - log(String) - Method in class com.rollbar.Rollbar
-
Deprecated.Record a debugging message at the default level of WARNING.
- log(String, Level) - Method in class com.rollbar.notifier.Rollbar
-
Record a message at the level specified.
- log(String, Level) - Method in class com.rollbar.Rollbar
-
Deprecated.Record a message at the level specified.
- log(String, Map<String, Object>) - Method in class com.rollbar.notifier.Rollbar
-
Record a message with custom data attached at the default level returned by
Rollbar.level(com.rollbar.notifier.config.Config, java.lang.Throwable), (WARNING unless level overridden). - log(String, Map<String, Object>) - Method in class com.rollbar.Rollbar
-
Deprecated.Record a message with extra information attached at the default level of WARNING.
- log(String, Map<String, Object>, Level) - Method in class com.rollbar.notifier.Rollbar
-
Record a message with custom data attached at the specified level.
- log(String, Map<String, Object>, Level) - Method in class com.rollbar.Rollbar
-
Deprecated.Record a message with extra information attached at the specified level.
- log(Throwable) - Method in class com.rollbar.notifier.Rollbar
-
Log an error at the level returned by
Rollbar.level(com.rollbar.notifier.config.Config, java.lang.Throwable). - log(Throwable) - Method in class com.rollbar.Rollbar
-
Deprecated.Log an error at the default level.
- log(Throwable, Level) - Method in class com.rollbar.notifier.Rollbar
-
Log an error at level specified.
- log(Throwable, Level) - Method in class com.rollbar.Rollbar
-
Deprecated.Log an error at level specified.
- log(Throwable, String) - Method in class com.rollbar.notifier.Rollbar
-
Record an error with human readable description at the default level returned by
Rollbar.level(com.rollbar.notifier.config.Config, java.lang.Throwable). - log(Throwable, String) - Method in class com.rollbar.Rollbar
-
Deprecated.Record an error with human readable description at the default level.
- log(Throwable, String, Level) - Method in class com.rollbar.notifier.Rollbar
-
Record a debug error with human readable description at the specified level.
- log(Throwable, String, Level) - Method in class com.rollbar.Rollbar
-
Deprecated.Record a debug error with human readable description at the specified level.
- log(Throwable, Thread, Map<String, Object>, String, Level, boolean) - Method in class com.rollbar.notifier.Rollbar
-
Record an error or message with extra data at the level specified.
- log(Throwable, Map<String, Object>) - Method in class com.rollbar.notifier.Rollbar
-
Record an error with custom data attached at the default level returned by
Rollbar.level(com.rollbar.notifier.config.Config, java.lang.Throwable). - log(Throwable, Map<String, Object>) - Method in class com.rollbar.Rollbar
-
Deprecated.Record an error with extra information attached at the default level.
- log(Throwable, Map<String, Object>, Level) - Method in class com.rollbar.notifier.Rollbar
-
Record an error with custom data attached at the level specified.
- log(Throwable, Map<String, Object>, Level) - Method in class com.rollbar.Rollbar
-
Deprecated.Record an error with extra information attached at the level specified.
- log(Throwable, Map<String, Object>, String) - Method in class com.rollbar.notifier.Rollbar
-
Record an error with custom data and human readable description at the default level returned by
Rollbar.level(com.rollbar.notifier.config.Config, java.lang.Throwable). - log(Throwable, Map<String, Object>, String) - Method in class com.rollbar.Rollbar
-
Deprecated.Record an error with custom parameters and human readable description at the default level.
- log(Throwable, Map<String, Object>, String, Level) - Method in class com.rollbar.notifier.Rollbar
-
Record an error or message with extra data at the level specified.
- log(Throwable, Map<String, Object>, String, Level) - Method in class com.rollbar.Rollbar
-
Deprecated.Record an error or message with extra data at the level specified.
- log(Throwable, Map<String, Object>, String, Level, boolean) - Method in class com.rollbar.notifier.Rollbar
-
Record an error or message with extra data at the level specified.
- log(Throwable, Map<String, Object>, String, Level, boolean) - Method in class com.rollbar.Rollbar
-
Deprecated.Record an error or message with extra data at the level specified.
M
- MAXIMUM_CAPACITY_FOR_TELEMETRY_EVENTS - Static variable in class com.rollbar.notifier.telemetry.RollbarTelemetryEventTracker
- maximumTelemetryData() - Method in interface com.rollbar.notifier.config.CommonConfig
- maximumTelemetryData(int) - Method in class com.rollbar.notifier.config.ConfigBuilder
-
Maximum Telemetry events sent in a payload, only for the default TelemetryEventTracker, if a custom implementation is used this value will be ignored.
- maxSize(int) - Method in class com.rollbar.notifier.sender.queue.DiskQueue.Builder
-
The max size of the queue.
N
- NONE - Enum constant in enum class com.rollbar.notifier.sender.SenderFailureStrategy.PayloadAction
-
No further action on the payload is necessary.
- notifier - Variable in class com.rollbar.notifier.config.ConfigBuilder
- notifier() - Method in interface com.rollbar.notifier.config.CommonConfig
-
Get the
notifierprovider. - notifier(Provider<Notifier>) - Method in class com.rollbar.notifier.config.ConfigBuilder
-
The provider to retrieve the
notifier. - NotifierProvider - Class in com.rollbar.notifier.provider.notifier
-
Default implementation to provide the
Notifier. - NotifierProvider() - Constructor for class com.rollbar.notifier.provider.notifier.NotifierProvider
O
- ObjectsUtils - Class in com.rollbar.notifier.util
-
Helper class that provides Java 7 features.
- ObjectsUtils() - Constructor for class com.rollbar.notifier.util.ObjectsUtils
- offer(Payload) - Method in class com.rollbar.notifier.sender.queue.DiskQueue
- onError(Payload, Exception) - Method in interface com.rollbar.notifier.sender.listener.SenderListener
-
This method is called every time there is an error in the process of sending the payloads to Rollbar or processing the Rollbar response.
- onError(Payload, Exception) - Method in class com.rollbar.notifier.sender.listener.SenderListenerCollection
- onResponse(Payload, Response) - Method in interface com.rollbar.notifier.sender.listener.SenderListener
-
This method is called every time the sender gets a response from Rollbar.
- onResponse(Payload, Response) - Method in class com.rollbar.notifier.sender.listener.SenderListenerCollection
P
- payloadTruncator - Variable in class com.rollbar.notifier.RollbarBase
- PayloadTruncator - Class in com.rollbar.notifier.truncation
- PayloadTruncator(JsonSerializer) - Constructor for class com.rollbar.notifier.truncation.PayloadTruncator
- PayloadTruncator.PayloadTruncationResult - Class in com.rollbar.notifier.truncation
- peek() - Method in class com.rollbar.notifier.sender.queue.DiskQueue
- person - Variable in class com.rollbar.notifier.config.ConfigBuilder
- person() - Method in interface com.rollbar.notifier.config.CommonConfig
-
Get the
personprovider. - person(Provider<Person>) - Method in class com.rollbar.notifier.config.ConfigBuilder
-
The provider to retrieve the
person. - platform - Variable in class com.rollbar.notifier.config.ConfigBuilder
- platform() - Method in interface com.rollbar.notifier.config.CommonConfig
-
Get the platform.
- platform(String) - Method in class com.rollbar.notifier.config.ConfigBuilder
-
The platform running (most likely JVM and a version).
- poll() - Method in class com.rollbar.notifier.sender.queue.DiskQueue
- postProcess(Data) - Method in interface com.rollbar.notifier.filter.Filter
-
Post-filter hook to decide once the final payload is ready if it should be send to Rollbar.
- postProcess(Data) - Method in class com.rollbar.notifier.filter.FilterPipeline
- preProcess(Level, Throwable, Map<String, Object>, String) - Method in interface com.rollbar.notifier.filter.Filter
-
Pre-filter hook to decide before gathering information and transforming the data if it is susceptible of it.
- preProcess(Level, Throwable, Map<String, Object>, String) - Method in class com.rollbar.notifier.filter.FilterPipeline
- process(ThrowableWrapper, Map<String, Object>, String, Level, boolean) - Method in class com.rollbar.notifier.RollbarBase
- processAppPackages(CommonConfig) - Method in class com.rollbar.notifier.RollbarBase
- provide() - Method in class com.rollbar.notifier.provider.notifier.NotifierProvider
- provide() - Method in interface com.rollbar.notifier.provider.Provider
-
Provides the value.
- provide() - Method in class com.rollbar.notifier.provider.server.ServerProvider
- provide() - Method in class com.rollbar.notifier.provider.timestamp.TimestampProvider
- provide(ConfigBuilder) - Method in interface com.rollbar.notifier.config.ConfigProvider
-
Provides the config given a builder.
- Provider<T> - Interface in com.rollbar.notifier.provider
-
Provider interface used to retrieve different data by
the notifierthrough theconfigsupplied to it. - proxy - Variable in class com.rollbar.notifier.config.ConfigBuilder
- proxy() - Method in interface com.rollbar.notifier.config.Config
-
Get the
proxy. - proxy(Proxy) - Method in class com.rollbar.notifier.config.ConfigBuilder
-
The
proxyto be used to send the data. - proxy(Proxy) - Method in class com.rollbar.notifier.sender.SyncSender.Builder
-
The
proxy.
Q
- queue() - Method in class com.rollbar.notifier.sender.BufferedSender
-
Get the queue.
- queue(Queue<Payload>) - Method in class com.rollbar.notifier.sender.BufferedSender.Builder
-
The queue.
- queueFolder(File) - Method in class com.rollbar.notifier.sender.queue.DiskQueue.Builder
-
The queue folder where persist the payloads.
R
- recordLogEventFor(Level, Source, String) - Method in class com.rollbar.notifier.telemetry.RollbarTelemetryEventTracker
- recordLogEventFor(Level, Source, String) - Method in interface com.rollbar.notifier.telemetry.TelemetryEventTracker
-
Record log telemetry event.
- recordLogEventFor(Level, String) - Method in class com.rollbar.notifier.RollbarBase
-
Record log telemetry event.
- recordManualEventFor(Level, Source, String) - Method in class com.rollbar.notifier.telemetry.RollbarTelemetryEventTracker
- recordManualEventFor(Level, Source, String) - Method in interface com.rollbar.notifier.telemetry.TelemetryEventTracker
-
Record manual telemetry event.
- recordManualEventFor(Level, String) - Method in class com.rollbar.notifier.RollbarBase
-
Record manual telemetry event.
- recordNavigationEventFor(Level, Source, String, String) - Method in class com.rollbar.notifier.telemetry.RollbarTelemetryEventTracker
- recordNavigationEventFor(Level, Source, String, String) - Method in interface com.rollbar.notifier.telemetry.TelemetryEventTracker
-
Record navigation telemetry event with from (origin) and to (destination).
- recordNavigationEventFor(Level, String, String) - Method in class com.rollbar.notifier.RollbarBase
-
Record navigation telemetry event with from (origin) and to (destination).
- recordNetworkEventFor(Level, Source, String, String, String) - Method in class com.rollbar.notifier.telemetry.RollbarTelemetryEventTracker
- recordNetworkEventFor(Level, Source, String, String, String) - Method in interface com.rollbar.notifier.telemetry.TelemetryEventTracker
-
Record network telemetry event with method, url, and status code.
- recordNetworkEventFor(Level, String, String, String) - Method in class com.rollbar.notifier.RollbarBase
-
Record network telemetry event with method, url, and status code.
- request - Variable in class com.rollbar.notifier.config.ConfigBuilder
- request() - Method in interface com.rollbar.notifier.config.CommonConfig
-
Get the
requestprovider. - request(Provider<Request>) - Method in class com.rollbar.notifier.config.ConfigBuilder
-
The provider to retrieve the
request. - requireNonNull(T, String) - Static method in class com.rollbar.notifier.util.ObjectsUtils
-
Checks that the specified object reference is not null.
- Response - Class in com.rollbar.notifier.sender.result
-
Represents the Rollbar response.
- Response.Builder - Class in com.rollbar.notifier.sender.result
-
Builder class for
Response. - result(Result) - Method in class com.rollbar.notifier.sender.result.Response.Builder
-
The Rollbar result.
- Result - Class in com.rollbar.notifier.sender.result
-
Represents the result returned by Rollbar.
- Result.Builder - Class in com.rollbar.notifier.sender.result
-
Builder class for
Result. - resultFrom(String) - Method in interface com.rollbar.notifier.sender.json.JsonSerializer
-
Parses the response from Rollbar to a
result. - resultFrom(String) - Method in class com.rollbar.notifier.sender.json.JsonSerializerImpl
- Rollbar - Class in com.rollbar.notifier
-
This is the current Rollbar notifier and the main starting point to send the data to Rollbar.
- Rollbar - Class in com.rollbar
-
Deprecated.
- Rollbar(Config) - Constructor for class com.rollbar.notifier.Rollbar
-
Constructor.
- Rollbar(String, String) - Constructor for class com.rollbar.Rollbar
-
Deprecated.Construct a notifier defaults for everything including Sender.
- Rollbar(String, String, Sender) - Constructor for class com.rollbar.Rollbar
-
Deprecated.Construct notifier, defaults for everything but Sender.
- Rollbar(String, String, Sender, String, String, String, String, String, Request, Person, Server, Map<String, Object>, Notifier, SenderListener, Filter, Transformer) - Constructor for class com.rollbar.Rollbar
-
Deprecated.Construct notifier with static values for all configuration options set.
- RollbarBase<RESULT,
C extends CommonConfig> - Class in com.rollbar.notifier -
Common logic for synchronous and non-blocking async notifiers.
- RollbarBase(C, BodyFactory, RESULT) - Constructor for class com.rollbar.notifier.RollbarBase
- RollbarTelemetryEventTracker - Class in com.rollbar.notifier.telemetry
-
Default implementation of
TelemetryEventTracker. - RollbarTelemetryEventTracker(Provider<Long>, int) - Constructor for class com.rollbar.notifier.telemetry.RollbarTelemetryEventTracker
-
Construct a
RollbarTelemetryEventTracker. - RollbarThreadStrategy - Class in com.rollbar.notifier.truncation
- RollbarThreadStrategy() - Constructor for class com.rollbar.notifier.truncation.RollbarThreadStrategy
- RollbarThrowableWrapper - Class in com.rollbar.notifier.wrapper
-
Implementation of the
throwable wrapper. - RollbarThrowableWrapper(String, String, StackTraceElement[], ThrowableWrapper) - Constructor for class com.rollbar.notifier.wrapper.RollbarThrowableWrapper
-
Constructor.
- RollbarThrowableWrapper(Throwable) - Constructor for class com.rollbar.notifier.wrapper.RollbarThrowableWrapper
-
Constructor.
- RollbarThrowableWrapper(Throwable, Thread) - Constructor for class com.rollbar.notifier.wrapper.RollbarThrowableWrapper
-
Constructor.
- RollbarThrowableWrapper(Throwable, List<RollbarThread>) - Constructor for class com.rollbar.notifier.wrapper.RollbarThrowableWrapper
-
Constructor.
- RollbarUncaughtExceptionHandler - Class in com.rollbar.notifier.uncaughtexception
-
Rollbar uncaught exception handler.
- RollbarUncaughtExceptionHandler(Rollbar, Thread.UncaughtExceptionHandler) - Constructor for class com.rollbar.notifier.uncaughtexception.RollbarUncaughtExceptionHandler
-
Constructor.
S
- send(Payload) - Method in class com.rollbar.notifier.sender.AbstractSender
- send(Payload) - Method in class com.rollbar.notifier.sender.BufferedSender
- send(Payload) - Method in interface com.rollbar.notifier.sender.Sender
-
Sends the payload getting notifications on the
send callbackpassed. - sender - Variable in class com.rollbar.notifier.config.ConfigBuilder
- sender() - Method in interface com.rollbar.notifier.config.Config
-
Get the
sender. - sender() - Method in class com.rollbar.notifier.sender.BufferedSender
-
Get the queue sender.
- sender(Sender) - Method in class com.rollbar.notifier.config.ConfigBuilder
-
The
sender. - sender(Sender) - Method in class com.rollbar.notifier.sender.BufferedSender.Builder
-
The sender.
- Sender - Interface in com.rollbar.notifier.sender
-
Sender interface to send the payload to Rollbar.
- SenderException - Exception in com.rollbar.notifier.sender.exception
-
Exception to indicate that there was a problem related in the
sender. - SenderException(Exception) - Constructor for exception com.rollbar.notifier.sender.exception.SenderException
- SenderException(Throwable) - Constructor for exception com.rollbar.notifier.sender.exception.SenderException
- senderFailureStrategy(SenderFailureStrategy) - Method in class com.rollbar.notifier.sender.BufferedSender.Builder
-
The strategy to use when sending fails.
- SenderFailureStrategy - Interface in com.rollbar.notifier.sender
-
Interface for strategy classes to deal with sending failures.
- SenderFailureStrategy.PayloadAction - Enum Class in com.rollbar.notifier.sender
- SenderListener - Interface in com.rollbar.notifier.sender.listener
-
Sender listener to be notified by the
Sender. - SenderListenerCollection - Class in com.rollbar.notifier.sender.listener
-
An append-only collection of listeners.
- SenderListenerCollection() - Constructor for class com.rollbar.notifier.sender.listener.SenderListenerCollection
- sendJsonPayload(String) - Method in class com.rollbar.notifier.Rollbar
-
Send JSON payload.
- sendPayload(Config, Payload) - Method in class com.rollbar.notifier.Rollbar
- sendPayload(C, Payload) - Method in class com.rollbar.notifier.RollbarBase
- server - Variable in class com.rollbar.notifier.config.ConfigBuilder
- server() - Method in interface com.rollbar.notifier.config.CommonConfig
-
Get the
serverprovider. - server(Provider<Server>) - Method in class com.rollbar.notifier.config.ConfigBuilder
-
The provider to retrieve the
server. - ServerProvider - Class in com.rollbar.notifier.provider.server
-
Server provider that populates the server's hostname.
- ServerProvider() - Constructor for class com.rollbar.notifier.provider.server.ServerProvider
- setError(Level) - Method in class com.rollbar.notifier.config.DefaultLevels
- setMessage(Level) - Method in class com.rollbar.notifier.config.DefaultLevels
- setThrowable(Level) - Method in class com.rollbar.notifier.config.DefaultLevels
- shouldCacheThrowable(Throwable, int) - Static method in class com.rollbar.jvmti.ThrowableCache
-
Whether or not we should cache this throwable which has a particular number of frames in its stacktrace.
- size() - Method in class com.rollbar.notifier.sender.queue.DiskQueue
- sizeInBytes(String) - Static method in class com.rollbar.notifier.truncation.PayloadTruncator
-
The size of the JSON string, as UTF-8 bytes.
- status(int) - Method in class com.rollbar.notifier.sender.result.Response.Builder
-
The status code of the response.
- SyncSender - Class in com.rollbar.notifier.sender
-
Synchronous implementation of the
sender. - SyncSender.Builder - Class in com.rollbar.notifier.sender
-
Builder class for
SyncSender.
T
- TelemetryEventsStrategy - Class in com.rollbar.notifier.truncation
- TelemetryEventsStrategy() - Constructor for class com.rollbar.notifier.truncation.TelemetryEventsStrategy
- telemetryEventTracker() - Method in interface com.rollbar.notifier.config.CommonConfig
- telemetryEventTracker(TelemetryEventTracker) - Method in class com.rollbar.notifier.config.ConfigBuilder
-
Set a
TelemetryEventTrackerimplementation. - TelemetryEventTracker - Interface in com.rollbar.notifier.telemetry
-
Collects and manages telemetry events that provide additional runtime context for error and message payloads.
- ThrowableCache - Class in com.rollbar.jvmti
-
ThrowableCache is a mechanism for storing information from the native interface at the time of an exception which can be queried later by the notifier for enhancing payloads.
- ThrowableWrapper - Interface in com.rollbar.notifier.wrapper
-
Throwable wrapper to wrap a
thowableor to represent a not available one. - timestamp - Variable in class com.rollbar.notifier.config.ConfigBuilder
- timestamp() - Method in interface com.rollbar.notifier.config.CommonConfig
- timestamp(Provider<Long>) - Method in class com.rollbar.notifier.config.ConfigBuilder
-
The provider to retrieve the timestamp.
- TimestampProvider - Class in com.rollbar.notifier.provider.timestamp
-
Provides the current timestamp from
System.currentTimeMillis(). - TimestampProvider() - Constructor for class com.rollbar.notifier.provider.timestamp.TimestampProvider
- toJson(Payload) - Method in interface com.rollbar.notifier.sender.json.JsonSerializer
-
Parses to a json the payload to be sent.
- toJson(Payload) - Method in class com.rollbar.notifier.sender.json.JsonSerializerImpl
- toJson(Map<String, Object>) - Method in class com.rollbar.notifier.sender.json.JsonSerializerImpl
-
Converts the map to a JSON string.
- toString() - Method in class com.rollbar.jvmti.CacheFrame
- toString() - Method in class com.rollbar.jvmti.LocalVariable
- toString() - Method in class com.rollbar.notifier.sender.result.Response
- toString() - Method in class com.rollbar.notifier.sender.result.Result
- toString() - Method in class com.rollbar.notifier.wrapper.RollbarThrowableWrapper
- transform(Data) - Method in interface com.rollbar.notifier.transformer.Transformer
-
Transforms the incoming data into other data that will be returned.
- transform(Data) - Method in class com.rollbar.notifier.transformer.TransformerPipeline
- transformer - Variable in class com.rollbar.notifier.config.ConfigBuilder
- transformer() - Method in interface com.rollbar.notifier.config.CommonConfig
-
Get the
transformer. - transformer(Transformer) - Method in class com.rollbar.notifier.config.ConfigBuilder
-
The provider to retrieve the
transformer. - Transformer - Interface in com.rollbar.notifier.transformer
-
Transformer interface to process the data before sending it to Rollbar..
- TransformerPipeline - Class in com.rollbar.notifier.transformer
-
Utility to create a pipeline of
transformersto transform thedata. - TransformerPipeline() - Constructor for class com.rollbar.notifier.transformer.TransformerPipeline
-
Constructor.
- TransformerPipeline(List<Transformer>) - Constructor for class com.rollbar.notifier.transformer.TransformerPipeline
-
Constructor.
- truncate(Payload) - Method in class com.rollbar.notifier.truncation.RollbarThreadStrategy
- truncate(Payload) - Method in class com.rollbar.notifier.truncation.TelemetryEventsStrategy
- truncate(Payload, int) - Method in class com.rollbar.notifier.truncation.PayloadTruncator
-
Attempts to truncate the payload so that its JSON representation, encoded as UTF-8, has size equal or less than the specified maximum size size.
- truncateLargePayloads - Variable in class com.rollbar.notifier.config.ConfigBuilder
- truncateLargePayloads() - Method in interface com.rollbar.notifier.config.CommonConfig
-
If set to true, the notifier will attempt to truncate payloads that are larger than the maximum size Rollbar allows.
- truncateLargePayloads(boolean) - Method in class com.rollbar.notifier.config.ConfigBuilder
-
If set to true, the notifier will attempt to truncate payloads that are larger than the maximum size Rollbar allows.
U
- uncaughtException(Thread, Throwable) - Method in class com.rollbar.notifier.uncaughtexception.RollbarUncaughtExceptionHandler
- url(String) - Method in class com.rollbar.notifier.sender.SyncSender.Builder
-
The url as string.
- url(URL) - Method in class com.rollbar.notifier.sender.SyncSender.Builder
-
The url as
URL. - UTF_8 - Static variable in class com.rollbar.notifier.sender.SyncSender
- uuidGenerator - Variable in class com.rollbar.notifier.config.ConfigBuilder
- uuidGenerator() - Method in interface com.rollbar.notifier.config.CommonConfig
-
Get the
UUID generator. - uuidGenerator(UuidGenerator) - Method in class com.rollbar.notifier.config.ConfigBuilder
-
The provider to retrieve the
uuid generator. - UuidGenerator - Interface in com.rollbar.notifier.uuid
-
Interface to generate the UUID of the
datato send to Rollbar.
V
- valueOf(String) - Static method in enum class com.rollbar.notifier.sender.SenderFailureStrategy.PayloadAction
-
Returns the enum constant of this class with the specified name.
- values() - Static method in enum class com.rollbar.notifier.sender.SenderFailureStrategy.PayloadAction
-
Returns an array containing the constants of this enum class, in the order they are declared.
W
- warning(String) - Method in class com.rollbar.notifier.Rollbar
-
Record a warning message.
- warning(String) - Method in class com.rollbar.Rollbar
-
Deprecated.Record a warning message.
- warning(String, Map<String, Object>) - Method in class com.rollbar.notifier.Rollbar
-
Record a warning message with custom data attached.
- warning(String, Map<String, Object>) - Method in class com.rollbar.Rollbar
-
Deprecated.Record a warning message with extra information attached.
- warning(Throwable) - Method in class com.rollbar.notifier.Rollbar
-
Record an error as a warning.
- warning(Throwable) - Method in class com.rollbar.Rollbar
-
Deprecated.Record an error as a warning.
- warning(Throwable, String) - Method in class com.rollbar.notifier.Rollbar
-
Record a warning with human readable description.
- warning(Throwable, String) - Method in class com.rollbar.Rollbar
-
Deprecated.Record a warning with human readable description.
- warning(Throwable, Map<String, Object>) - Method in class com.rollbar.notifier.Rollbar
-
Record a warning error with custom data attached.
- warning(Throwable, Map<String, Object>) - Method in class com.rollbar.Rollbar
-
Deprecated.Record a warning error with extra information attached.
- warning(Throwable, Map<String, Object>, String) - Method in class com.rollbar.notifier.Rollbar
-
Record a warning error with data and human readable description.
- warning(Throwable, Map<String, Object>, String) - Method in class com.rollbar.Rollbar
-
Deprecated.Record a warning error with custom parameters and human readable description.
- withAccessToken(String) - Static method in class com.rollbar.notifier.config.ConfigBuilder
-
Initializes a config builder instance with the access token supplied.
- withConfig(Config) - Static method in class com.rollbar.notifier.config.ConfigBuilder
-
Initializes a config builder instance with the values set in the supplied config.
- wrapThrowable(Throwable) - Method in class com.rollbar.notifier.RollbarBase
- wrapThrowable(Throwable, Thread) - Method in class com.rollbar.notifier.RollbarBase
All Classes and Interfaces|All Packages|Constant Field Values|Serialized Form
BodyFactory.from(ThrowableWrapper, String).