All Classes and Interfaces
Class
Description
Base class to implement
senders.
Implementations based on this class should just implement the AbstractSender.doSend(com.rollbar.api.payload.Payload)
method and not have to deal with listener and notifications to them.Represents an error return by the Rollbar API.
Body factory helper to build the proper body depending on the throwable or the description.
A buffered sender implementation.
Builder class for
BufferedSender.CacheFrame is a frame generated from the native interface to hold a method and a list of local
variables for later use.
Rollbar notifier settings are common to all types of notifier (sync and async).
The configuration for the
notifier.Configuration builder to build the
configuration of the rollbar
notifier.Static helper for the ConfigProvider class.
Holds the default level configuration for ocurrence reporting of different types.
A
queue of payloads persisted on disk.Builder class for
DiskQueue.Filter interface.
Interface to generate the fingerprint of the
data to send to Rollbar.Serializer to be used by the
sender.Implementation of the
json serializer.LocalVariable is a data object reprsenting a live variable in a stack frame at the time of an
exception gathered by the native interface.
Default implementation to provide the
Notifier.Helper class that provides Java 7 features.
Provider interface used to retrieve different data by
the notifier through the
config supplied to it.Represents the Rollbar response.
Builder class for
Response.Represents the result returned by Rollbar.
Builder class for
Result.This is the current Rollbar notifier and the main starting point to send the data to Rollbar.
Deprecated.
Common logic for synchronous and non-blocking async notifiers.
Default implementation of
TelemetryEventTracker.Implementation of the
throwable wrapper.Rollbar uncaught exception handler.
Sender interface to send the payload to Rollbar.
Exception to indicate that there was a problem related in the
sender.Interface for strategy classes to deal with sending failures.
Sender listener to be notified by the
Sender.An append-only collection of listeners.
Server provider that populates the server's hostname.
Synchronous implementation of the
sender.Builder class for
SyncSender.Collects and manages telemetry events that provide additional runtime
context for error and message payloads.
ThrowableCache is a mechanism for storing information from the native interface at the time
of an exception which can be queried later by the notifier for enhancing payloads.
Throwable wrapper to wrap a
thowable or to represent a not available one.Provides the current timestamp from
System.currentTimeMillis().Transformer interface to process the data before sending it to Rollbar..
Utility to create a pipeline of
transformers to transform
the data.Interface to generate the UUID of the
data to send to Rollbar.