Package com.rollbar
Class Rollbar
java.lang.Object
com.rollbar.Rollbar
Deprecated.
This class is deprecated and provided as a convenience to ease the migration path.
from 0.5.4 to 1.0.0. For the simplest use cases, this class should provide the same
functionality as the old com.rollbar.Rollbar class by delegating to the new
com.rollbar.notifier.Rollbar class. For any new usage, do not use this class, prefer
com.rollbar.notifier.Rollbar.
-
Constructor Summary
ConstructorsConstructorDescriptionDeprecated.Construct a notifier defaults for everything including Sender.Deprecated.Construct notifier, defaults for everything but Sender.Rollbar(String accessToken, String environment, Sender sender, String codeVersion, String platform, String language, String framework, String context, com.rollbar.api.payload.data.Request request, com.rollbar.api.payload.data.Person person, com.rollbar.api.payload.data.Server server, Map<String, Object> custom, com.rollbar.api.payload.data.Notifier notifier, SenderListener responseHandler, Filter filter, Transformer transform) Deprecated.Construct notifier with static values for all configuration options set. -
Method Summary
Modifier and TypeMethodDescriptionvoidDeprecated.Record a critical message.voidDeprecated.Record a critical message with extra information attached.voidDeprecated.Record a critical error.voidDeprecated.Record a critical error with human readable description.voidDeprecated.Record a critical error with extra information attached.voidDeprecated.Record a critical error with custom parameters and human readable description.voidDeprecated.Record a debugging message.voidDeprecated.Record a debugging message with extra information attached.voidDeprecated.Record an error as debugging information.voidDeprecated.Record a debug error with human readable description.voidDeprecated.Record a debug error with extra information attached.voidDeprecated.Record a debug error with custom parameters and human readable description.voidDeprecated.Record an error message.voidDeprecated.Record a error message with extra information attached.voidDeprecated.Record an error.voidDeprecated.Record an error with human readable description.voidDeprecated.Record an error with extra information attached.voidDeprecated.Record an error with custom parameters and human readable description.voidDeprecated.Handle all uncaught errors on current thread with this `Rollbar`.voidhandleUncaughtErrors(Thread thread) Deprecated.Handle all uncaught errors onthreadwith this `Rollbar`.voidDeprecated.Record an informational message.voidDeprecated.Record an informational message with extra information attached.voidDeprecated.Record an error as an info.voidDeprecated.Record an info error with human readable description.voidDeprecated.Record an info error with extra information attached.voidDeprecated.Record an info error with custom parameters and human readable description.voidDeprecated.Record a debugging message at the default level of WARNING.voidDeprecated.Record a message at the level specified.voidDeprecated.Record a message with extra information attached at the default level of WARNING.voidDeprecated.Record a message with extra information attached at the specified level.voidDeprecated.Log an error at the default level.voidDeprecated.Log an error at level specified.voidDeprecated.Record an error with human readable description at the default level.voidDeprecated.Record a debug error with human readable description at the specified level.voidDeprecated.Record an error with extra information attached at the default level.voidDeprecated.Record an error with extra information attached at the level specified.voidDeprecated.Record an error with custom parameters and human readable description at the default level.voidlog(Throwable error, Map<String, Object> custom, String description, com.rollbar.api.payload.data.Level level) Deprecated.Record an error or message with extra data at the level specified.voidlog(Throwable error, Map<String, Object> custom, String description, com.rollbar.api.payload.data.Level level, boolean isUncaught) Deprecated.Record an error or message with extra data at the level specified.voidDeprecated.Record a warning message.voidDeprecated.Record a warning message with extra information attached.voidDeprecated.Record an error as a warning.voidDeprecated.Record a warning with human readable description.voidDeprecated.Record a warning error with extra information attached.voidDeprecated.Record a warning error with custom parameters and human readable description.
-
Constructor Details
-
Rollbar
Deprecated.Construct a notifier defaults for everything including Sender. Caution: default sender is slow and blocking. Consider providing a Sender overload.- Parameters:
accessToken- not nullable, the access token to send payloads toenvironment- not nullable, the environment to send payloads under
-
Rollbar
Deprecated.Construct notifier, defaults for everything but Sender.- Parameters:
accessToken- not nullable, the access token to send payloads toenvironment- not nullable, the environment to send payloads undersender- the sender to use. If null uses default:Sender
-
Rollbar
public Rollbar(String accessToken, String environment, Sender sender, String codeVersion, String platform, String language, String framework, String context, com.rollbar.api.payload.data.Request request, com.rollbar.api.payload.data.Person person, com.rollbar.api.payload.data.Server server, Map<String, Object> custom, com.rollbar.api.payload.data.Notifier notifier, SenderListener responseHandler, Filter filter, Transformer transform) Deprecated.Construct notifier with static values for all configuration options set. Anything left null will use the default value. If appropriate.- Parameters:
accessToken- not nullable, the access token to send payloads toenvironment- not nullable, the environment to send payloads undersender- the sender to use. If null uses default:SendercodeVersion- the version of the code currently running. If code checked out on server: `git rev-parse HEAD`platform- the platform you're running. (JVM version, or similar).language- the main language you're running ("java" by default, override w/ "clojure", "scala" etc.).framework- the framework you're using ("Play", "Spring", etc.).context- a mnemonic for finding the code responsible (e.g. controller name, module name)request- the HTTP request that triggered this error. Can be set if the IOC container can work per-request.person- the affected person. Can be set if the IOC container can work per-request.server- info about this server. This can be statically set.custom- custom info to send with *every* error. Can be dynamically or statically set.notifier- information about this notifier. Defaultnew Notifier()(Notifier.responseHandler- what to do with the response. Use this to check for failures and handle some other way.filter- filter used to determine if you will send payload. Receives *transformed* payload.transform- alter payload before sending.
-
-
Method Details
-
handleUncaughtErrors
public void handleUncaughtErrors()Deprecated.Handle all uncaught errors on current thread with this `Rollbar`. -
handleUncaughtErrors
Deprecated.Handle all uncaught errors onthreadwith this `Rollbar`.- Parameters:
thread- the thread to handle errors on
-
critical
Deprecated.Record a critical error.- Parameters:
error- the error
-
error
Deprecated.Record an error.- Parameters:
error- the error
-
warning
Deprecated.Record an error as a warning.- Parameters:
error- the error
-
info
Deprecated.Record an error as an info.- Parameters:
error- the error
-
debug
Deprecated.Record an error as debugging information.- Parameters:
error- the error
-
log
Deprecated.Log an error at the default level.- Parameters:
error- the error
-
log
Deprecated.Log an error at level specified.- Parameters:
error- the errorlevel- the level of the error
-
critical
Deprecated.Record a critical error with extra information attached.- Parameters:
error- the errorcustom- the extra information
-
error
Deprecated.Record an error with extra information attached.- Parameters:
error- the errorcustom- the extra information
-
warning
Deprecated.Record a warning error with extra information attached.- Parameters:
error- the errorcustom- the extra information
-
info
Deprecated.Record an info error with extra information attached.- Parameters:
error- the errorcustom- the extra information
-
debug
Deprecated.Record a debug error with extra information attached.- Parameters:
error- the errorcustom- the extra information
-
log
Deprecated.Record an error with extra information attached at the default level.- Parameters:
error- the errorcustom- the extra information
-
log
public void log(Throwable error, Map<String, Object> custom, com.rollbar.api.payload.data.Level level) Deprecated.Record an error with extra information attached at the level specified.- Parameters:
error- the errorcustom- the extra informationlevel- the level
-
critical
Deprecated.Record a critical error with human readable description.- Parameters:
error- the errordescription- human readable description of error
-
error
Deprecated.Record an error with human readable description.- Parameters:
error- the errordescription- human readable description of error
-
warning
Deprecated.Record a warning with human readable description.- Parameters:
error- the errordescription- human readable description of error
-
info
Deprecated.Record an info error with human readable description.- Parameters:
error- the errordescription- human readable description of error
-
debug
Deprecated.Record a debug error with human readable description.- Parameters:
error- the errordescription- human readable description of error
-
log
Deprecated.Record an error with human readable description at the default level.- Parameters:
error- the errordescription- human readable description of error
-
log
Deprecated.Record a debug error with human readable description at the specified level.- Parameters:
error- the errordescription- human readable description of errorlevel- the level
-
critical
Deprecated.Record a critical error with custom parameters and human readable description.- Parameters:
error- the errorcustom- the custom datadescription- the human readable description of error
-
error
Deprecated.Record an error with custom parameters and human readable description.- Parameters:
error- the errorcustom- the custom datadescription- the human readable description of error
-
warning
Deprecated.Record a warning error with custom parameters and human readable description.- Parameters:
error- the errorcustom- the custom datadescription- the human readable description of error
-
info
Deprecated.Record an info error with custom parameters and human readable description.- Parameters:
error- the errorcustom- the custom datadescription- the human readable description of error
-
debug
Deprecated.Record a debug error with custom parameters and human readable description.- Parameters:
error- the errorcustom- the custom datadescription- the human readable description of error
-
log
Deprecated.Record an error with custom parameters and human readable description at the default level.- Parameters:
error- the errorcustom- the custom datadescription- the human readable description of error
-
critical
Deprecated.Record a critical message.- Parameters:
message- the message
-
error
Deprecated.Record an error message.- Parameters:
message- the message
-
warning
Deprecated.Record a warning message.- Parameters:
message- the message
-
info
Deprecated.Record an informational message.- Parameters:
message- the message
-
debug
Deprecated.Record a debugging message.- Parameters:
message- the message
-
log
Deprecated.Record a debugging message at the default level of WARNING.- Parameters:
message- the message
-
log
Deprecated.Record a message at the level specified.- Parameters:
message- the messagelevel- the level
-
critical
Deprecated.Record a critical message with extra information attached.- Parameters:
message- the messagecustom- the extra information
-
error
Deprecated.Record a error message with extra information attached.- Parameters:
message- the messagecustom- the extra information
-
warning
Deprecated.Record a warning message with extra information attached.- Parameters:
message- the messagecustom- the extra information
-
info
Deprecated.Record an informational message with extra information attached.- Parameters:
message- the messagecustom- the extra information
-
debug
Deprecated.Record a debugging message with extra information attached.- Parameters:
message- the messagecustom- the extra information
-
log
Deprecated.Record a message with extra information attached at the default level of WARNING.- Parameters:
message- the messagecustom- the extra information
-
log
public void log(String message, Map<String, Object> custom, com.rollbar.api.payload.data.Level level) Deprecated.Record a message with extra information attached at the specified level.- Parameters:
message- the messagecustom- the extra informationlevel- the level
-
log
public void log(Throwable error, Map<String, Object> custom, String description, com.rollbar.api.payload.data.Level level) Deprecated.Record an error or message with extra data at the level specified. At least ene of `error` or `description` must be non-null. If error is null, `description` will be sent as a message. If error is non-null, description will be sent as the description of the error. Custom data will be attached to message if the error is null.- Parameters:
error- the error (if any)custom- the custom data (if any)description- the description of the error, or the message to sendlevel- the level to send it at
-
log
public void log(Throwable error, Map<String, Object> custom, String description, com.rollbar.api.payload.data.Level level, boolean isUncaught) Deprecated.Record an error or message with extra data at the level specified. At least ene of `error` or `description` must be non-null. If error is null, `description` will be sent as a message. If error is non-null, description will be sent as the description of the error. Custom data will be attached to message if the error is null.- Parameters:
error- the error (if any)custom- the custom data (if any)description- the description of the error, or the message to sendlevel- the level to send it atisUncaught- whether or not this set of data originates from an uncaught exception.
-