Package com.rollbar.jvmti
Class CacheFrame
java.lang.Object
com.rollbar.jvmti.CacheFrame
CacheFrame is a frame generated from the native interface to hold a method and a list of local
variables for later use.
-
Constructor Summary
ConstructorsConstructorDescriptionCacheFrame(Method method, LocalVariable[] locals) Constructor with the method and list of local variables. -
Method Summary