Package com.rollbar.jvmti
Class LocalVariable
java.lang.Object
com.rollbar.jvmti.LocalVariable
LocalVariable is a data object reprsenting a live variable in a stack frame at the time of an
exception gathered by the native interface.
-
Constructor Summary
ConstructorsConstructorDescriptionLocalVariable(String name, Object value) Constructor with the variable name and value. -
Method Summary