Package com.rollbar.notifier.config
Interface CommonConfig
- All Known Subinterfaces:
Config
public interface CommonConfig
Rollbar notifier settings are common to all types of notifier (sync and async).
-
Method Summary
Modifier and TypeMethodDescriptionGet the access token.Get the list of packages considered to be in your app.Provider<com.rollbar.api.payload.data.Client>client()Get theclientprovider.Get the code version.context()Get the context provider.custom()Get the customprovider.com.rollbar.api.payload.data.LevelLevel to use as the default for Errors if one is not otherwise specified.com.rollbar.api.payload.data.LevelLevel to use as the default for messages if one is not otherwise specified.com.rollbar.api.payload.data.LevelLevel to use as the default for non-Error Throwables if one is not otherwise specified.endpoint()Get the Rollbar endpoint.Get the environment.filter()Get thefilter.Get thefingerprint generator.Get the framework.booleanFlag to indicate that the Rollbar notifier should handle the uncaught errors.booleanFlag to indicate that the Rollbar notifier should be enabled/disabled.The serializer to convert a payload to JSON.language()Get the language.intProvider<com.rollbar.api.payload.data.Notifier>notifier()Get thenotifierprovider.Provider<com.rollbar.api.payload.data.Person>person()Get thepersonprovider.platform()Get the platform.Provider<com.rollbar.api.payload.data.Request>request()Get therequestprovider.Provider<com.rollbar.api.payload.data.Server>server()Get theserverprovider.Get thetransformer.booleanIf set to true, the notifier will attempt to truncate payloads that are larger than the maximum size Rollbar allows.Get theUUID generator.
-
Method Details
-
accessToken
String accessToken()Get the access token.- Returns:
- the Rollbar access token.
-
endpoint
String endpoint()Get the Rollbar endpoint.- Returns:
- the Rollbar endpoint.
-
environment
String environment()Get the environment.- Returns:
- the environment.
-
codeVersion
String codeVersion()Get the code version.- Returns:
- the code version.
-
platform
String platform()Get the platform.- Returns:
- the platform.
-
language
String language()Get the language.- Returns:
- the language.
-
framework
String framework()Get the framework.- Returns:
- the framework.
-
context
Get the context provider.- Returns:
- the context.
-
request
Provider<com.rollbar.api.payload.data.Request> request()Get therequestprovider.- Returns:
- the request.
-
person
Provider<com.rollbar.api.payload.data.Person> person()Get thepersonprovider.- Returns:
- the person.
-
server
Provider<com.rollbar.api.payload.data.Server> server()Get theserverprovider.- Returns:
- the server.
-
client
Provider<com.rollbar.api.payload.data.Client> client()Get theclientprovider.- Returns:
- the server.
-
custom
Get the customprovider.- Returns:
- the provider of any custom values.
-
notifier
Provider<com.rollbar.api.payload.data.Notifier> notifier()Get thenotifierprovider.- Returns:
- the provider of the notifier data.
-
timestamp
- Returns:
- the provider of a timestamp.
-
filter
Filter filter()Get thefilter.- Returns:
- the filter.
-
transformer
Transformer transformer()Get thetransformer.- Returns:
- the transformer.
-
fingerPrintGenerator
FingerprintGenerator fingerPrintGenerator()Get thefingerprint generator.- Returns:
- the fingerprint.
-
uuidGenerator
UuidGenerator uuidGenerator()Get theUUID generator.- Returns:
- the uuid generator.
-
jsonSerializer
JsonSerializer jsonSerializer()The serializer to convert a payload to JSON.- Returns:
- The
instance.
-
appPackages
Get the list of packages considered to be in your app.- Returns:
- the list of packages.
-
handleUncaughtErrors
boolean handleUncaughtErrors()Flag to indicate that the Rollbar notifier should handle the uncaught errors.- Returns:
- true to handle otherwise false.
-
isEnabled
boolean isEnabled()Flag to indicate that the Rollbar notifier should be enabled/disabled.- Returns:
- true if enabled otherwise false.
-
defaultMessageLevel
com.rollbar.api.payload.data.Level defaultMessageLevel()Level to use as the default for messages if one is not otherwise specified.- Returns:
- the level.
-
defaultErrorLevel
com.rollbar.api.payload.data.Level defaultErrorLevel()Level to use as the default for Errors if one is not otherwise specified.- Returns:
- the level.
-
defaultThrowableLevel
com.rollbar.api.payload.data.Level defaultThrowableLevel()Level to use as the default for non-Error Throwables if one is not otherwise specified.- Returns:
- the level.
-
truncateLargePayloads
boolean truncateLargePayloads()If set to true, the notifier will attempt to truncate payloads that are larger than the maximum size Rollbar allows. Default: false.
- Returns:
- true to truncate payloads otherwise false.
-
maximumTelemetryData
int maximumTelemetryData() -
telemetryEventTracker
TelemetryEventTracker telemetryEventTracker()
-