Package com.rollbar.notifier.util
Class BodyFactory
java.lang.Object
com.rollbar.notifier.util.BodyFactory
Body factory helper to build the proper body depending on the throwable or the description.
-
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptioncom.rollbar.api.payload.data.body.Bodyfrom(ThrowableWrapper throwableWrapper, String description) Builds the body from thethrowableWrapperand the description supplied.com.rollbar.api.payload.data.body.Bodyfrom(ThrowableWrapper throwableWrapper, String description, List<com.rollbar.api.payload.data.TelemetryEvent> telemetryEvents) Builds the body from thethrowableWrapper, the description supplied and telemetry events.com.rollbar.api.payload.data.body.Groupfrom(StackTraceElement[] stackTraceElements) Builds a Group from an Array of StackTraceElement.com.rollbar.api.payload.data.body.RollbarThreadBuilds a RollbarThread from a Thread.com.rollbar.api.payload.data.body.BodyDeprecated.
-
Constructor Details
-
BodyFactory
public BodyFactory()
-
-
Method Details
-
from
@Deprecated public com.rollbar.api.payload.data.body.Body from(Throwable throwable, String description) Deprecated.Replaced byfrom(ThrowableWrapper, String).Builds the body for the throwable and description supplied.- Parameters:
throwable- the throwable.description- the description.- Returns:
- the body.
-
from
public com.rollbar.api.payload.data.body.Body from(ThrowableWrapper throwableWrapper, String description) Builds the body from thethrowableWrapperand the description supplied.- Parameters:
throwableWrapper- the throwable proxy.description- the description.- Returns:
- the body.
-
from
public com.rollbar.api.payload.data.body.Body from(ThrowableWrapper throwableWrapper, String description, List<com.rollbar.api.payload.data.TelemetryEvent> telemetryEvents) Builds the body from thethrowableWrapper, the description supplied and telemetry events.- Parameters:
throwableWrapper- the throwable proxy.description- the description.telemetryEvents- the telemetry events.- Returns:
- the body.
-
from
Builds a RollbarThread from a Thread.- Parameters:
thread- the thread.- Returns:
- the RollbarThread.
-
from
Builds a Group from an Array of StackTraceElement.- Parameters:
stackTraceElements- the stack trace elements.- Returns:
- the Group.
-
from(ThrowableWrapper, String).