Package com.rollbar.notifier.wrapper
Interface ThrowableWrapper
- All Known Implementing Classes:
RollbarThrowableWrapper
public interface ThrowableWrapper
Throwable wrapper to wrap a
thowable or to represent a not available one.-
Method Summary
Modifier and TypeMethodDescriptionGet a map of stack traces for all live threads in the moment of the Exception.getCause()Get thethrowable wrappedcause.Get thethrowableclass name.Get thethrowablemessage.com.rollbar.api.payload.data.body.RollbarThreadGet the RollbarThreadrollbarThread.List<com.rollbar.api.payload.data.body.RollbarThread>Get a list of the RollbarThreads for this error.Get thethrowablestack trace elements.Get the wrappedthrowable.
-
Method Details
-
getClassName
String getClassName()Get thethrowableclass name.- Returns:
- the class name.
-
getMessage
String getMessage()Get thethrowablemessage.- Returns:
- the message.
-
getStackTrace
StackTraceElement[] getStackTrace()Get thethrowablestack trace elements.- Returns:
- the stack trace elements.
-
getCause
ThrowableWrapper getCause()Get thethrowable wrappedcause.- Returns:
- the cause.
-
getThrowable
Throwable getThrowable()Get the wrappedthrowable.- Returns:
- the throwable.
-
getRollbarThread
com.rollbar.api.payload.data.body.RollbarThread getRollbarThread()Get the RollbarThreadrollbarThread.- Returns:
- the rollbarThread.
-
getAllStackTraces
Map<Thread,StackTraceElement[]> getAllStackTraces()Get a map of stack traces for all live threads in the moment of the Exception.- Returns:
- the map.
-
getRollbarThreads
List<com.rollbar.api.payload.data.body.RollbarThread> getRollbarThreads()Get a list of the RollbarThreads for this error.- Returns:
- the RollbarThreads.
-